redvox.cloud.api_m_fqns API documentation

# Module `redvox.cloud.api_m_fqns`

Expand source code

    METADATA: str = "metadata"
    METADATA_API: str = "metadata.api"
    METADATA_SUB_API: str = "metadata.sub_api"
    METADATA_STATION_INFORMATION: str = "metadata.station_information"
    METADATA_STATION_INFORMATION_ID: str = "metadata.station_information.id"
    METADATA_STATION_INFORMATION_UUID: str = "metadata.station_information.uuid"
    METADATA_STATION_INFORMATION_DESCRIPTION: str = (
        "metadata.station_information.description"
    )
    METADATA_STATION_INFORMATION_AUTH_ID: str = "metadata.station_information.auth_id"
    METADATA_STATION_INFORMATION_MAKE: str = "metadata.station_information.make"
    METADATA_STATION_INFORMATION_MODEL: str = "metadata.station_information.model"
    METADATA_STATION_INFORMATION_OS: str = "metadata.station_information.os"
    METADATA_STATION_INFORMATION_OS_VERSION: str = "metadata.station_information.os_version"
    METADATA_STATION_INFORMATION_APP_VERSION: str = (
        "metadata.station_information.app_version"
    )
    METADATA_STATION_INFORMATION_IS_PRIVATE: str = "metadata.station_information.is_private"
    METADATA_STATION_INFORMATION_APP_SETTINGS: str = (
        "metadata.station_information.app_settings"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_AUDIO_SAMPLING_RATE: str = (
        "metadata.station_information.app_settings.audio_sampling_rate"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_SAMPLES_PER_WINDOW: str = (
        "metadata.station_information.app_settings.samples_per_window"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_AUDIO_SOURCE_TUNING: str = (
        "metadata.station_information.app_settings.audio_source_tuning"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_ADDITIONAL_INPUT_SENSORS: str = (
        "metadata.station_information.app_settings.additional_input_sensors"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_AUTOMATICALLY_RECORD: str = (
        "metadata.station_information.app_settings.automatically_record"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_LAUNCH_AT_POWER_UP: str = (
        "metadata.station_information.app_settings.launch_at_power_up"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_STATION_ID: str = (
        "metadata.station_information.app_settings.station_id"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_STATION_DESCRIPTION: str = (
        "metadata.station_information.app_settings.station_description"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_PUSH_TO_SERVER: str = (
        "metadata.station_information.app_settings.push_to_server"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_PUBLISH_DATA_AS_PRIVATE: str = (
        "metadata.station_information.app_settings.publish_data_as_private"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_SCRAMBLE_AUDIO_DATA: str = (
        "metadata.station_information.app_settings.scramble_audio_data"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_PROVIDE_BACKFILL: str = (
        "metadata.station_information.app_settings.provide_backfill"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_REMOVE_SENSOR_DC_OFFSET: str = (
        "metadata.station_information.app_settings.remove_sensor_dc_offset"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_FFT_OVERLAP: str = (
        "metadata.station_information.app_settings.fft_overlap"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_USE_CUSTOM_TIME_SYNC_SERVER: str = (
        "metadata.station_information.app_settings.use_custom_time_sync_server"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_TIME_SYNC_SERVER_URL: str = (
        "metadata.station_information.app_settings.time_sync_server_url"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_USE_CUSTOM_DATA_SERVER: str = (
        "metadata.station_information.app_settings.use_custom_data_server"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_DATA_SERVER_URL: str = (
        "metadata.station_information.app_settings.data_server_url"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_USE_CUSTOM_AUTH_SERVER: str = (
        "metadata.station_information.app_settings.use_custom_auth_server"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_AUTH_SERVER_URL: str = (
        "metadata.station_information.app_settings.auth_server_url"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_AUTO_DELETE_DATA_FILES: str = (
        "metadata.station_information.app_settings.auto_delete_data_files"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_STORAGE_SPACE_ALLOWANCE: str = (
        "metadata.station_information.app_settings.storage_space_allowance"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_USE_SD_CARD_FOR_DATA_STORAGE: str = (
        "metadata.station_information.app_settings.use_sd_card_for_data_storage"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_USE_LOCATION_SERVICES: str = (
        "metadata.station_information.app_settings.use_location_services"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_USE_LATITUDE: str = (
        "metadata.station_information.app_settings.use_latitude"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_USE_LONGITUDE: str = (
        "metadata.station_information.app_settings.use_longitude"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_USE_ALTITUDE: str = (
        "metadata.station_information.app_settings.use_altitude"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_METRICS_RATE: str = (
        "metadata.station_information.app_settings.metrics_rate"
    )
    METADATA_STATION_INFORMATION_APP_SETTINGS_METADATA: str = (
        "metadata.station_information.app_settings.metadata"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS: str = (
        "metadata.station_information.station_metrics"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS: str = (
        "metadata.station_information.station_metrics.timestamps"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_UNIT: str = (
        "metadata.station_information.station_metrics.timestamps.unit"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.station_information.station_metrics.timestamps.timestamps"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.station_information.station_metrics.timestamps.timestamp_statistics"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.station_information.station_metrics.timestamps.timestamp_statistics.count"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.station_information.station_metrics.timestamps.timestamp_statistics.mean"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = "metadata.station_information.station_metrics.timestamps.timestamp_statistics.standard_deviation"
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.station_information.station_metrics.timestamps.timestamp_statistics.min"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.station_information.station_metrics.timestamps.timestamp_statistics.max"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.station_information.station_metrics.timestamps.timestamp_statistics.range"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = "metadata.station_information.station_metrics.timestamps.timestamp_statistics.metadata"
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.station_information.station_metrics.timestamps.mean_sample_rate"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.station_information.station_metrics.timestamps.stdev_sample_rate"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TIMESTAMPS_METADATA: str = (
        "metadata.station_information.station_metrics.timestamps.metadata"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_TYPE: str = (
        "metadata.station_information.station_metrics.network_type"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_CELL_SERVICE_STATE: str = (
        "metadata.station_information.station_metrics.cell_service_state"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_STRENGTH: str = (
        "metadata.station_information.station_metrics.network_strength"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_STRENGTH_UNIT: str = (
        "metadata.station_information.station_metrics.network_strength.unit"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_STRENGTH_VALUES: str = (
        "metadata.station_information.station_metrics.network_strength.values"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_STRENGTH_VALUE_STATISTICS: str = (
        "metadata.station_information.station_metrics.network_strength.value_statistics"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_STRENGTH_VALUE_STATISTICS_COUNT: str = "metadata.station_information.station_metrics.network_strength.value_statistics.count"
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_STRENGTH_VALUE_STATISTICS_MEAN: str = "metadata.station_information.station_metrics.network_strength.value_statistics.mean"
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_STRENGTH_VALUE_STATISTICS_STANDARD_DEVIATION: str = "metadata.station_information.station_metrics.network_strength.value_statistics.standard_deviation"
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_STRENGTH_VALUE_STATISTICS_MIN: str = (
        "metadata.station_information.station_metrics.network_strength.value_statistics.min"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_STRENGTH_VALUE_STATISTICS_MAX: str = (
        "metadata.station_information.station_metrics.network_strength.value_statistics.max"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_STRENGTH_VALUE_STATISTICS_RANGE: str = "metadata.station_information.station_metrics.network_strength.value_statistics.range"
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_STRENGTH_VALUE_STATISTICS_METADATA: str = "metadata.station_information.station_metrics.network_strength.value_statistics.metadata"
    METADATA_STATION_INFORMATION_STATION_METRICS_NETWORK_STRENGTH_METADATA: str = (
        "metadata.station_information.station_metrics.network_strength.metadata"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TEMPERATURE: str = (
        "metadata.station_information.station_metrics.temperature"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TEMPERATURE_UNIT: str = (
        "metadata.station_information.station_metrics.temperature.unit"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TEMPERATURE_VALUES: str = (
        "metadata.station_information.station_metrics.temperature.values"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TEMPERATURE_VALUE_STATISTICS: str = (
        "metadata.station_information.station_metrics.temperature.value_statistics"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TEMPERATURE_VALUE_STATISTICS_COUNT: str = (
        "metadata.station_information.station_metrics.temperature.value_statistics.count"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TEMPERATURE_VALUE_STATISTICS_MEAN: str = (
        "metadata.station_information.station_metrics.temperature.value_statistics.mean"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TEMPERATURE_VALUE_STATISTICS_STANDARD_DEVIATION: str = "metadata.station_information.station_metrics.temperature.value_statistics.standard_deviation"
    METADATA_STATION_INFORMATION_STATION_METRICS_TEMPERATURE_VALUE_STATISTICS_MIN: str = (
        "metadata.station_information.station_metrics.temperature.value_statistics.min"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TEMPERATURE_VALUE_STATISTICS_MAX: str = (
        "metadata.station_information.station_metrics.temperature.value_statistics.max"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TEMPERATURE_VALUE_STATISTICS_RANGE: str = (
        "metadata.station_information.station_metrics.temperature.value_statistics.range"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TEMPERATURE_VALUE_STATISTICS_METADATA: str = (
        "metadata.station_information.station_metrics.temperature.value_statistics.metadata"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_TEMPERATURE_METADATA: str = (
        "metadata.station_information.station_metrics.temperature.metadata"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY: str = (
        "metadata.station_information.station_metrics.battery"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_UNIT: str = (
        "metadata.station_information.station_metrics.battery.unit"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_VALUES: str = (
        "metadata.station_information.station_metrics.battery.values"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_VALUE_STATISTICS: str = (
        "metadata.station_information.station_metrics.battery.value_statistics"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_VALUE_STATISTICS_COUNT: str = (
        "metadata.station_information.station_metrics.battery.value_statistics.count"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_VALUE_STATISTICS_MEAN: str = (
        "metadata.station_information.station_metrics.battery.value_statistics.mean"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_VALUE_STATISTICS_STANDARD_DEVIATION: str = "metadata.station_information.station_metrics.battery.value_statistics.standard_deviation"
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_VALUE_STATISTICS_MIN: str = (
        "metadata.station_information.station_metrics.battery.value_statistics.min"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_VALUE_STATISTICS_MAX: str = (
        "metadata.station_information.station_metrics.battery.value_statistics.max"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_VALUE_STATISTICS_RANGE: str = (
        "metadata.station_information.station_metrics.battery.value_statistics.range"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_VALUE_STATISTICS_METADATA: str = (
        "metadata.station_information.station_metrics.battery.value_statistics.metadata"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_METADATA: str = (
        "metadata.station_information.station_metrics.battery.metadata"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_CURRENT: str = (
        "metadata.station_information.station_metrics.battery_current"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_CURRENT_UNIT: str = (
        "metadata.station_information.station_metrics.battery_current.unit"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_CURRENT_VALUES: str = (
        "metadata.station_information.station_metrics.battery_current.values"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_CURRENT_VALUE_STATISTICS: str = (
        "metadata.station_information.station_metrics.battery_current.value_statistics"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_CURRENT_VALUE_STATISTICS_COUNT: str = "metadata.station_information.station_metrics.battery_current.value_statistics.count"
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_CURRENT_VALUE_STATISTICS_MEAN: str = (
        "metadata.station_information.station_metrics.battery_current.value_statistics.mean"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_CURRENT_VALUE_STATISTICS_STANDARD_DEVIATION: str = "metadata.station_information.station_metrics.battery_current.value_statistics.standard_deviation"
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_CURRENT_VALUE_STATISTICS_MIN: str = (
        "metadata.station_information.station_metrics.battery_current.value_statistics.min"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_CURRENT_VALUE_STATISTICS_MAX: str = (
        "metadata.station_information.station_metrics.battery_current.value_statistics.max"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_CURRENT_VALUE_STATISTICS_RANGE: str = "metadata.station_information.station_metrics.battery_current.value_statistics.range"
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_CURRENT_VALUE_STATISTICS_METADATA: str = "metadata.station_information.station_metrics.battery_current.value_statistics.metadata"
    METADATA_STATION_INFORMATION_STATION_METRICS_BATTERY_CURRENT_METADATA: str = (
        "metadata.station_information.station_metrics.battery_current.metadata"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_RAM: str = (
        "metadata.station_information.station_metrics.available_ram"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_RAM_UNIT: str = (
        "metadata.station_information.station_metrics.available_ram.unit"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_RAM_VALUES: str = (
        "metadata.station_information.station_metrics.available_ram.values"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_RAM_VALUE_STATISTICS: str = (
        "metadata.station_information.station_metrics.available_ram.value_statistics"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_RAM_VALUE_STATISTICS_COUNT: str = (
        "metadata.station_information.station_metrics.available_ram.value_statistics.count"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_RAM_VALUE_STATISTICS_MEAN: str = (
        "metadata.station_information.station_metrics.available_ram.value_statistics.mean"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_RAM_VALUE_STATISTICS_STANDARD_DEVIATION: str = "metadata.station_information.station_metrics.available_ram.value_statistics.standard_deviation"
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_RAM_VALUE_STATISTICS_MIN: str = (
        "metadata.station_information.station_metrics.available_ram.value_statistics.min"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_RAM_VALUE_STATISTICS_MAX: str = (
        "metadata.station_information.station_metrics.available_ram.value_statistics.max"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_RAM_VALUE_STATISTICS_RANGE: str = (
        "metadata.station_information.station_metrics.available_ram.value_statistics.range"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_RAM_VALUE_STATISTICS_METADATA: str = "metadata.station_information.station_metrics.available_ram.value_statistics.metadata"
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_RAM_METADATA: str = (
        "metadata.station_information.station_metrics.available_ram.metadata"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_DISK: str = (
        "metadata.station_information.station_metrics.available_disk"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_DISK_UNIT: str = (
        "metadata.station_information.station_metrics.available_disk.unit"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_DISK_VALUES: str = (
        "metadata.station_information.station_metrics.available_disk.values"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_DISK_VALUE_STATISTICS: str = (
        "metadata.station_information.station_metrics.available_disk.value_statistics"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_DISK_VALUE_STATISTICS_COUNT: str = (
        "metadata.station_information.station_metrics.available_disk.value_statistics.count"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_DISK_VALUE_STATISTICS_MEAN: str = (
        "metadata.station_information.station_metrics.available_disk.value_statistics.mean"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_DISK_VALUE_STATISTICS_STANDARD_DEVIATION: str = "metadata.station_information.station_metrics.available_disk.value_statistics.standard_deviation"
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_DISK_VALUE_STATISTICS_MIN: str = (
        "metadata.station_information.station_metrics.available_disk.value_statistics.min"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_DISK_VALUE_STATISTICS_MAX: str = (
        "metadata.station_information.station_metrics.available_disk.value_statistics.max"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_DISK_VALUE_STATISTICS_RANGE: str = (
        "metadata.station_information.station_metrics.available_disk.value_statistics.range"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_DISK_VALUE_STATISTICS_METADATA: str = "metadata.station_information.station_metrics.available_disk.value_statistics.metadata"
    METADATA_STATION_INFORMATION_STATION_METRICS_AVAILABLE_DISK_METADATA: str = (
        "metadata.station_information.station_metrics.available_disk.metadata"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_CPU_UTILIZATION: str = (
        "metadata.station_information.station_metrics.cpu_utilization"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_CPU_UTILIZATION_UNIT: str = (
        "metadata.station_information.station_metrics.cpu_utilization.unit"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_CPU_UTILIZATION_VALUES: str = (
        "metadata.station_information.station_metrics.cpu_utilization.values"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_CPU_UTILIZATION_VALUE_STATISTICS: str = (
        "metadata.station_information.station_metrics.cpu_utilization.value_statistics"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_CPU_UTILIZATION_VALUE_STATISTICS_COUNT: str = "metadata.station_information.station_metrics.cpu_utilization.value_statistics.count"
    METADATA_STATION_INFORMATION_STATION_METRICS_CPU_UTILIZATION_VALUE_STATISTICS_MEAN: str = (
        "metadata.station_information.station_metrics.cpu_utilization.value_statistics.mean"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_CPU_UTILIZATION_VALUE_STATISTICS_STANDARD_DEVIATION: str = "metadata.station_information.station_metrics.cpu_utilization.value_statistics.standard_deviation"
    METADATA_STATION_INFORMATION_STATION_METRICS_CPU_UTILIZATION_VALUE_STATISTICS_MIN: str = (
        "metadata.station_information.station_metrics.cpu_utilization.value_statistics.min"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_CPU_UTILIZATION_VALUE_STATISTICS_MAX: str = (
        "metadata.station_information.station_metrics.cpu_utilization.value_statistics.max"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_CPU_UTILIZATION_VALUE_STATISTICS_RANGE: str = "metadata.station_information.station_metrics.cpu_utilization.value_statistics.range"
    METADATA_STATION_INFORMATION_STATION_METRICS_CPU_UTILIZATION_VALUE_STATISTICS_METADATA: str = "metadata.station_information.station_metrics.cpu_utilization.value_statistics.metadata"
    METADATA_STATION_INFORMATION_STATION_METRICS_CPU_UTILIZATION_METADATA: str = (
        "metadata.station_information.station_metrics.cpu_utilization.metadata"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_POWER_STATE: str = (
        "metadata.station_information.station_metrics.power_state"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_WIFI_WAKE_LOCK: str = (
        "metadata.station_information.station_metrics.wifi_wake_lock"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_STATE: str = (
        "metadata.station_information.station_metrics.screen_state"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_BRIGHTNESS: str = (
        "metadata.station_information.station_metrics.screen_brightness"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_BRIGHTNESS_UNIT: str = (
        "metadata.station_information.station_metrics.screen_brightness.unit"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_BRIGHTNESS_VALUES: str = (
        "metadata.station_information.station_metrics.screen_brightness.values"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_BRIGHTNESS_VALUE_STATISTICS: str = (
        "metadata.station_information.station_metrics.screen_brightness.value_statistics"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_BRIGHTNESS_VALUE_STATISTICS_COUNT: str = "metadata.station_information.station_metrics.screen_brightness.value_statistics.count"
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_BRIGHTNESS_VALUE_STATISTICS_MEAN: str = "metadata.station_information.station_metrics.screen_brightness.value_statistics.mean"
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_BRIGHTNESS_VALUE_STATISTICS_STANDARD_DEVIATION: str = "metadata.station_information.station_metrics.screen_brightness.value_statistics.standard_deviation"
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_BRIGHTNESS_VALUE_STATISTICS_MIN: str = "metadata.station_information.station_metrics.screen_brightness.value_statistics.min"
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_BRIGHTNESS_VALUE_STATISTICS_MAX: str = "metadata.station_information.station_metrics.screen_brightness.value_statistics.max"
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_BRIGHTNESS_VALUE_STATISTICS_RANGE: str = "metadata.station_information.station_metrics.screen_brightness.value_statistics.range"
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_BRIGHTNESS_VALUE_STATISTICS_METADATA: str = "metadata.station_information.station_metrics.screen_brightness.value_statistics.metadata"
    METADATA_STATION_INFORMATION_STATION_METRICS_SCREEN_BRIGHTNESS_METADATA: str = (
        "metadata.station_information.station_metrics.screen_brightness.metadata"
    )
    METADATA_STATION_INFORMATION_STATION_METRICS_METADATA: str = (
        "metadata.station_information.station_metrics.metadata"
    )
    METADATA_STATION_INFORMATION_SERVICE_URLS: str = (
        "metadata.station_information.service_urls"
    )
    METADATA_STATION_INFORMATION_SERVICE_URLS_AUTH_SERVER: str = (
        "metadata.station_information.service_urls.auth_server"
    )
    METADATA_STATION_INFORMATION_SERVICE_URLS_SYNCH_SERVER: str = (
        "metadata.station_information.service_urls.synch_server"
    )
    METADATA_STATION_INFORMATION_SERVICE_URLS_ACQUISITION_SERVER: str = (
        "metadata.station_information.service_urls.acquisition_server"
    )
    METADATA_STATION_INFORMATION_SERVICE_URLS_METADATA: str = (
        "metadata.station_information.service_urls.metadata"
    )
    METADATA_STATION_INFORMATION_METADATA: str = "metadata.station_information.metadata"
    METADATA_TIMING_INFORMATION: str = "metadata.timing_information"
    METADATA_TIMING_INFORMATION_PACKET_START_OS_TIMESTAMP: str = (
        "metadata.timing_information.packet_start_os_timestamp"
    )
    METADATA_TIMING_INFORMATION_PACKET_START_MACH_TIMESTAMP: str = (
        "metadata.timing_information.packet_start_mach_timestamp"
    )
    METADATA_TIMING_INFORMATION_PACKET_END_OS_TIMESTAMP: str = (
        "metadata.timing_information.packet_end_os_timestamp"
    )
    METADATA_TIMING_INFORMATION_PACKET_END_MACH_TIMESTAMP: str = (
        "metadata.timing_information.packet_end_mach_timestamp"
    )
    METADATA_TIMING_INFORMATION_SERVER_ACQUISITION_ARRIVAL_TIMESTAMP: str = (
        "metadata.timing_information.server_acquisition_arrival_timestamp"
    )
    METADATA_TIMING_INFORMATION_APP_START_MACH_TIMESTAMP: str = (
        "metadata.timing_information.app_start_mach_timestamp"
    )
    METADATA_TIMING_INFORMATION_SYNCH_EXCHANGES: str = (
        "metadata.timing_information.synch_exchanges"
    )
    METADATA_TIMING_INFORMATION_SYNCH_EXCHANGES_A1: str = (
        "metadata.timing_information.synch_exchanges.a1"
    )
    METADATA_TIMING_INFORMATION_SYNCH_EXCHANGES_A2: str = (
        "metadata.timing_information.synch_exchanges.a2"
    )
    METADATA_TIMING_INFORMATION_SYNCH_EXCHANGES_A3: str = (
        "metadata.timing_information.synch_exchanges.a3"
    )
    METADATA_TIMING_INFORMATION_SYNCH_EXCHANGES_B1: str = (
        "metadata.timing_information.synch_exchanges.b1"
    )
    METADATA_TIMING_INFORMATION_SYNCH_EXCHANGES_B2: str = (
        "metadata.timing_information.synch_exchanges.b2"
    )
    METADATA_TIMING_INFORMATION_SYNCH_EXCHANGES_B3: str = (
        "metadata.timing_information.synch_exchanges.b3"
    )
    METADATA_TIMING_INFORMATION_SYNCH_EXCHANGES_UNIT: str = (
        "metadata.timing_information.synch_exchanges.unit"
    )
    METADATA_TIMING_INFORMATION_SYNCH_EXCHANGES_METADATA: str = (
        "metadata.timing_information.synch_exchanges.metadata"
    )
    METADATA_TIMING_INFORMATION_BEST_LATENCY: str = (
        "metadata.timing_information.best_latency"
    )
    METADATA_TIMING_INFORMATION_BEST_OFFSET: str = "metadata.timing_information.best_offset"
    METADATA_TIMING_INFORMATION_SCORE: str = "metadata.timing_information.score"
    METADATA_TIMING_INFORMATION_SCORE_METHOD: str = (
        "metadata.timing_information.score_method"
    )
    METADATA_TIMING_INFORMATION_UNIT: str = "metadata.timing_information.unit"
    METADATA_TIMING_INFORMATION_METADATA: str = "metadata.timing_information.metadata"
    METADATA_SENSORS: str = "metadata.sensors"
    METADATA_SENSORS_ACCELEROMETER: str = "metadata.sensors.accelerometer"
    METADATA_SENSORS_ACCELEROMETER_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.accelerometer.sensor_description"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS: str = (
        "metadata.sensors.accelerometer.timestamps"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.accelerometer.timestamps.unit"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.accelerometer.timestamps.timestamps"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.accelerometer.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.accelerometer.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.accelerometer.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.accelerometer.timestamps.timestamp_statistics.standard_deviation"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.accelerometer.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.accelerometer.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.accelerometer.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.accelerometer.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.accelerometer.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.accelerometer.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_ACCELEROMETER_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.accelerometer.timestamps.metadata"
    )
    METADATA_SENSORS_ACCELEROMETER_X_SAMPLES: str = (
        "metadata.sensors.accelerometer.x_samples"
    )
    METADATA_SENSORS_ACCELEROMETER_X_SAMPLES_UNIT: str = (
        "metadata.sensors.accelerometer.x_samples.unit"
    )
    METADATA_SENSORS_ACCELEROMETER_X_SAMPLES_VALUES: str = (
        "metadata.sensors.accelerometer.x_samples.values"
    )
    METADATA_SENSORS_ACCELEROMETER_X_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.accelerometer.x_samples.value_statistics"
    )
    METADATA_SENSORS_ACCELEROMETER_X_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.accelerometer.x_samples.value_statistics.count"
    )
    METADATA_SENSORS_ACCELEROMETER_X_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.accelerometer.x_samples.value_statistics.mean"
    )
    METADATA_SENSORS_ACCELEROMETER_X_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.accelerometer.x_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_ACCELEROMETER_X_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.accelerometer.x_samples.value_statistics.min"
    )
    METADATA_SENSORS_ACCELEROMETER_X_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.accelerometer.x_samples.value_statistics.max"
    )
    METADATA_SENSORS_ACCELEROMETER_X_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.accelerometer.x_samples.value_statistics.range"
    )
    METADATA_SENSORS_ACCELEROMETER_X_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.accelerometer.x_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_ACCELEROMETER_X_SAMPLES_METADATA: str = (
        "metadata.sensors.accelerometer.x_samples.metadata"
    )
    METADATA_SENSORS_ACCELEROMETER_Y_SAMPLES: str = (
        "metadata.sensors.accelerometer.y_samples"
    )
    METADATA_SENSORS_ACCELEROMETER_Y_SAMPLES_UNIT: str = (
        "metadata.sensors.accelerometer.y_samples.unit"
    )
    METADATA_SENSORS_ACCELEROMETER_Y_SAMPLES_VALUES: str = (
        "metadata.sensors.accelerometer.y_samples.values"
    )
    METADATA_SENSORS_ACCELEROMETER_Y_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.accelerometer.y_samples.value_statistics"
    )
    METADATA_SENSORS_ACCELEROMETER_Y_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.accelerometer.y_samples.value_statistics.count"
    )
    METADATA_SENSORS_ACCELEROMETER_Y_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.accelerometer.y_samples.value_statistics.mean"
    )
    METADATA_SENSORS_ACCELEROMETER_Y_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.accelerometer.y_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_ACCELEROMETER_Y_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.accelerometer.y_samples.value_statistics.min"
    )
    METADATA_SENSORS_ACCELEROMETER_Y_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.accelerometer.y_samples.value_statistics.max"
    )
    METADATA_SENSORS_ACCELEROMETER_Y_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.accelerometer.y_samples.value_statistics.range"
    )
    METADATA_SENSORS_ACCELEROMETER_Y_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.accelerometer.y_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_ACCELEROMETER_Y_SAMPLES_METADATA: str = (
        "metadata.sensors.accelerometer.y_samples.metadata"
    )
    METADATA_SENSORS_ACCELEROMETER_Z_SAMPLES: str = (
        "metadata.sensors.accelerometer.z_samples"
    )
    METADATA_SENSORS_ACCELEROMETER_Z_SAMPLES_UNIT: str = (
        "metadata.sensors.accelerometer.z_samples.unit"
    )
    METADATA_SENSORS_ACCELEROMETER_Z_SAMPLES_VALUES: str = (
        "metadata.sensors.accelerometer.z_samples.values"
    )
    METADATA_SENSORS_ACCELEROMETER_Z_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.accelerometer.z_samples.value_statistics"
    )
    METADATA_SENSORS_ACCELEROMETER_Z_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.accelerometer.z_samples.value_statistics.count"
    )
    METADATA_SENSORS_ACCELEROMETER_Z_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.accelerometer.z_samples.value_statistics.mean"
    )
    METADATA_SENSORS_ACCELEROMETER_Z_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.accelerometer.z_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_ACCELEROMETER_Z_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.accelerometer.z_samples.value_statistics.min"
    )
    METADATA_SENSORS_ACCELEROMETER_Z_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.accelerometer.z_samples.value_statistics.max"
    )
    METADATA_SENSORS_ACCELEROMETER_Z_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.accelerometer.z_samples.value_statistics.range"
    )
    METADATA_SENSORS_ACCELEROMETER_Z_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.accelerometer.z_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_ACCELEROMETER_Z_SAMPLES_METADATA: str = (
        "metadata.sensors.accelerometer.z_samples.metadata"
    )
    METADATA_SENSORS_ACCELEROMETER_METADATA: str = "metadata.sensors.accelerometer.metadata"
    METADATA_SENSORS_AMBIENT_TEMPERATURE: str = "metadata.sensors.ambient_temperature"
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.ambient_temperature.sensor_description"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS: str = (
        "metadata.sensors.ambient_temperature.timestamps"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.ambient_temperature.timestamps.unit"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.ambient_temperature.timestamps.timestamps"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.ambient_temperature.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.ambient_temperature.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.ambient_temperature.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = "metadata.sensors.ambient_temperature.timestamps.timestamp_statistics.standard_deviation"
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.ambient_temperature.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.ambient_temperature.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.ambient_temperature.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.ambient_temperature.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.ambient_temperature.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.ambient_temperature.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.ambient_temperature.timestamps.metadata"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SAMPLES: str = (
        "metadata.sensors.ambient_temperature.samples"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SAMPLES_UNIT: str = (
        "metadata.sensors.ambient_temperature.samples.unit"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SAMPLES_VALUES: str = (
        "metadata.sensors.ambient_temperature.samples.values"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.ambient_temperature.samples.value_statistics"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.ambient_temperature.samples.value_statistics.count"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.ambient_temperature.samples.value_statistics.mean"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.ambient_temperature.samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.ambient_temperature.samples.value_statistics.min"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.ambient_temperature.samples.value_statistics.max"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.ambient_temperature.samples.value_statistics.range"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.ambient_temperature.samples.value_statistics.metadata"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_SAMPLES_METADATA: str = (
        "metadata.sensors.ambient_temperature.samples.metadata"
    )
    METADATA_SENSORS_AMBIENT_TEMPERATURE_METADATA: str = (
        "metadata.sensors.ambient_temperature.metadata"
    )
    METADATA_SENSORS_AUDIO: str = "metadata.sensors.audio"
    METADATA_SENSORS_AUDIO_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.audio.sensor_description"
    )
    METADATA_SENSORS_AUDIO_FIRST_SAMPLE_TIMESTAMP: str = (
        "metadata.sensors.audio.first_sample_timestamp"
    )
    METADATA_SENSORS_AUDIO_SAMPLE_RATE: str = "metadata.sensors.audio.sample_rate"
    METADATA_SENSORS_AUDIO_BITS_OF_PRECISION: str = (
        "metadata.sensors.audio.bits_of_precision"
    )
    METADATA_SENSORS_AUDIO_IS_SCRAMBLED: str = "metadata.sensors.audio.is_scrambled"
    METADATA_SENSORS_AUDIO_ENCODING: str = "metadata.sensors.audio.encoding"
    METADATA_SENSORS_AUDIO_SAMPLES: str = "metadata.sensors.audio.samples"
    METADATA_SENSORS_AUDIO_SAMPLES_UNIT: str = "metadata.sensors.audio.samples.unit"
    METADATA_SENSORS_AUDIO_SAMPLES_VALUES: str = "metadata.sensors.audio.samples.values"
    METADATA_SENSORS_AUDIO_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.audio.samples.value_statistics"
    )
    METADATA_SENSORS_AUDIO_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.audio.samples.value_statistics.count"
    )
    METADATA_SENSORS_AUDIO_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.audio.samples.value_statistics.mean"
    )
    METADATA_SENSORS_AUDIO_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.audio.samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_AUDIO_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.audio.samples.value_statistics.min"
    )
    METADATA_SENSORS_AUDIO_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.audio.samples.value_statistics.max"
    )
    METADATA_SENSORS_AUDIO_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.audio.samples.value_statistics.range"
    )
    METADATA_SENSORS_AUDIO_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.audio.samples.value_statistics.metadata"
    )
    METADATA_SENSORS_AUDIO_SAMPLES_METADATA: str = "metadata.sensors.audio.samples.metadata"
    METADATA_SENSORS_AUDIO_METADATA: str = "metadata.sensors.audio.metadata"
    METADATA_SENSORS_COMPRESSED_AUDIO: str = "metadata.sensors.compressed_audio"
    METADATA_SENSORS_COMPRESSED_AUDIO_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.compressed_audio.sensor_description"
    )
    METADATA_SENSORS_COMPRESSED_AUDIO_FIRST_SAMPLE_TIMESTAMP: str = (
        "metadata.sensors.compressed_audio.first_sample_timestamp"
    )
    METADATA_SENSORS_COMPRESSED_AUDIO_SAMPLE_RATE: str = (
        "metadata.sensors.compressed_audio.sample_rate"
    )
    METADATA_SENSORS_COMPRESSED_AUDIO_IS_SCRAMBLED: str = (
        "metadata.sensors.compressed_audio.is_scrambled"
    )
    METADATA_SENSORS_COMPRESSED_AUDIO_AUDIO_BYTES: str = (
        "metadata.sensors.compressed_audio.audio_bytes"
    )
    METADATA_SENSORS_COMPRESSED_AUDIO_AUDIO_CODEC: str = (
        "metadata.sensors.compressed_audio.audio_codec"
    )
    METADATA_SENSORS_COMPRESSED_AUDIO_METADATA: str = (
        "metadata.sensors.compressed_audio.metadata"
    )
    METADATA_SENSORS_GRAVITY: str = "metadata.sensors.gravity"
    METADATA_SENSORS_GRAVITY_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.gravity.sensor_description"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS: str = "metadata.sensors.gravity.timestamps"
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.gravity.timestamps.unit"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.gravity.timestamps.timestamps"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.gravity.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.gravity.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.gravity.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.gravity.timestamps.timestamp_statistics.standard_deviation"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.gravity.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.gravity.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.gravity.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.gravity.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.gravity.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.gravity.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_GRAVITY_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.gravity.timestamps.metadata"
    )
    METADATA_SENSORS_GRAVITY_X_SAMPLES: str = "metadata.sensors.gravity.x_samples"
    METADATA_SENSORS_GRAVITY_X_SAMPLES_UNIT: str = "metadata.sensors.gravity.x_samples.unit"
    METADATA_SENSORS_GRAVITY_X_SAMPLES_VALUES: str = (
        "metadata.sensors.gravity.x_samples.values"
    )
    METADATA_SENSORS_GRAVITY_X_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.gravity.x_samples.value_statistics"
    )
    METADATA_SENSORS_GRAVITY_X_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.gravity.x_samples.value_statistics.count"
    )
    METADATA_SENSORS_GRAVITY_X_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.gravity.x_samples.value_statistics.mean"
    )
    METADATA_SENSORS_GRAVITY_X_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.gravity.x_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_GRAVITY_X_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.gravity.x_samples.value_statistics.min"
    )
    METADATA_SENSORS_GRAVITY_X_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.gravity.x_samples.value_statistics.max"
    )
    METADATA_SENSORS_GRAVITY_X_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.gravity.x_samples.value_statistics.range"
    )
    METADATA_SENSORS_GRAVITY_X_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.gravity.x_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_GRAVITY_X_SAMPLES_METADATA: str = (
        "metadata.sensors.gravity.x_samples.metadata"
    )
    METADATA_SENSORS_GRAVITY_Y_SAMPLES: str = "metadata.sensors.gravity.y_samples"
    METADATA_SENSORS_GRAVITY_Y_SAMPLES_UNIT: str = "metadata.sensors.gravity.y_samples.unit"
    METADATA_SENSORS_GRAVITY_Y_SAMPLES_VALUES: str = (
        "metadata.sensors.gravity.y_samples.values"
    )
    METADATA_SENSORS_GRAVITY_Y_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.gravity.y_samples.value_statistics"
    )
    METADATA_SENSORS_GRAVITY_Y_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.gravity.y_samples.value_statistics.count"
    )
    METADATA_SENSORS_GRAVITY_Y_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.gravity.y_samples.value_statistics.mean"
    )
    METADATA_SENSORS_GRAVITY_Y_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.gravity.y_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_GRAVITY_Y_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.gravity.y_samples.value_statistics.min"
    )
    METADATA_SENSORS_GRAVITY_Y_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.gravity.y_samples.value_statistics.max"
    )
    METADATA_SENSORS_GRAVITY_Y_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.gravity.y_samples.value_statistics.range"
    )
    METADATA_SENSORS_GRAVITY_Y_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.gravity.y_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_GRAVITY_Y_SAMPLES_METADATA: str = (
        "metadata.sensors.gravity.y_samples.metadata"
    )
    METADATA_SENSORS_GRAVITY_Z_SAMPLES: str = "metadata.sensors.gravity.z_samples"
    METADATA_SENSORS_GRAVITY_Z_SAMPLES_UNIT: str = "metadata.sensors.gravity.z_samples.unit"
    METADATA_SENSORS_GRAVITY_Z_SAMPLES_VALUES: str = (
        "metadata.sensors.gravity.z_samples.values"
    )
    METADATA_SENSORS_GRAVITY_Z_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.gravity.z_samples.value_statistics"
    )
    METADATA_SENSORS_GRAVITY_Z_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.gravity.z_samples.value_statistics.count"
    )
    METADATA_SENSORS_GRAVITY_Z_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.gravity.z_samples.value_statistics.mean"
    )
    METADATA_SENSORS_GRAVITY_Z_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.gravity.z_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_GRAVITY_Z_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.gravity.z_samples.value_statistics.min"
    )
    METADATA_SENSORS_GRAVITY_Z_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.gravity.z_samples.value_statistics.max"
    )
    METADATA_SENSORS_GRAVITY_Z_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.gravity.z_samples.value_statistics.range"
    )
    METADATA_SENSORS_GRAVITY_Z_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.gravity.z_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_GRAVITY_Z_SAMPLES_METADATA: str = (
        "metadata.sensors.gravity.z_samples.metadata"
    )
    METADATA_SENSORS_GRAVITY_METADATA: str = "metadata.sensors.gravity.metadata"
    METADATA_SENSORS_GYROSCOPE: str = "metadata.sensors.gyroscope"
    METADATA_SENSORS_GYROSCOPE_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.gyroscope.sensor_description"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS: str = "metadata.sensors.gyroscope.timestamps"
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.gyroscope.timestamps.unit"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.gyroscope.timestamps.timestamps"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.gyroscope.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.gyroscope.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.gyroscope.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.gyroscope.timestamps.timestamp_statistics.standard_deviation"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.gyroscope.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.gyroscope.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.gyroscope.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.gyroscope.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.gyroscope.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.gyroscope.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_GYROSCOPE_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.gyroscope.timestamps.metadata"
    )
    METADATA_SENSORS_GYROSCOPE_X_SAMPLES: str = "metadata.sensors.gyroscope.x_samples"
    METADATA_SENSORS_GYROSCOPE_X_SAMPLES_UNIT: str = (
        "metadata.sensors.gyroscope.x_samples.unit"
    )
    METADATA_SENSORS_GYROSCOPE_X_SAMPLES_VALUES: str = (
        "metadata.sensors.gyroscope.x_samples.values"
    )
    METADATA_SENSORS_GYROSCOPE_X_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.gyroscope.x_samples.value_statistics"
    )
    METADATA_SENSORS_GYROSCOPE_X_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.gyroscope.x_samples.value_statistics.count"
    )
    METADATA_SENSORS_GYROSCOPE_X_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.gyroscope.x_samples.value_statistics.mean"
    )
    METADATA_SENSORS_GYROSCOPE_X_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.gyroscope.x_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_GYROSCOPE_X_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.gyroscope.x_samples.value_statistics.min"
    )
    METADATA_SENSORS_GYROSCOPE_X_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.gyroscope.x_samples.value_statistics.max"
    )
    METADATA_SENSORS_GYROSCOPE_X_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.gyroscope.x_samples.value_statistics.range"
    )
    METADATA_SENSORS_GYROSCOPE_X_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.gyroscope.x_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_GYROSCOPE_X_SAMPLES_METADATA: str = (
        "metadata.sensors.gyroscope.x_samples.metadata"
    )
    METADATA_SENSORS_GYROSCOPE_Y_SAMPLES: str = "metadata.sensors.gyroscope.y_samples"
    METADATA_SENSORS_GYROSCOPE_Y_SAMPLES_UNIT: str = (
        "metadata.sensors.gyroscope.y_samples.unit"
    )
    METADATA_SENSORS_GYROSCOPE_Y_SAMPLES_VALUES: str = (
        "metadata.sensors.gyroscope.y_samples.values"
    )
    METADATA_SENSORS_GYROSCOPE_Y_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.gyroscope.y_samples.value_statistics"
    )
    METADATA_SENSORS_GYROSCOPE_Y_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.gyroscope.y_samples.value_statistics.count"
    )
    METADATA_SENSORS_GYROSCOPE_Y_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.gyroscope.y_samples.value_statistics.mean"
    )
    METADATA_SENSORS_GYROSCOPE_Y_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.gyroscope.y_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_GYROSCOPE_Y_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.gyroscope.y_samples.value_statistics.min"
    )
    METADATA_SENSORS_GYROSCOPE_Y_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.gyroscope.y_samples.value_statistics.max"
    )
    METADATA_SENSORS_GYROSCOPE_Y_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.gyroscope.y_samples.value_statistics.range"
    )
    METADATA_SENSORS_GYROSCOPE_Y_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.gyroscope.y_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_GYROSCOPE_Y_SAMPLES_METADATA: str = (
        "metadata.sensors.gyroscope.y_samples.metadata"
    )
    METADATA_SENSORS_GYROSCOPE_Z_SAMPLES: str = "metadata.sensors.gyroscope.z_samples"
    METADATA_SENSORS_GYROSCOPE_Z_SAMPLES_UNIT: str = (
        "metadata.sensors.gyroscope.z_samples.unit"
    )
    METADATA_SENSORS_GYROSCOPE_Z_SAMPLES_VALUES: str = (
        "metadata.sensors.gyroscope.z_samples.values"
    )
    METADATA_SENSORS_GYROSCOPE_Z_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.gyroscope.z_samples.value_statistics"
    )
    METADATA_SENSORS_GYROSCOPE_Z_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.gyroscope.z_samples.value_statistics.count"
    )
    METADATA_SENSORS_GYROSCOPE_Z_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.gyroscope.z_samples.value_statistics.mean"
    )
    METADATA_SENSORS_GYROSCOPE_Z_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.gyroscope.z_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_GYROSCOPE_Z_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.gyroscope.z_samples.value_statistics.min"
    )
    METADATA_SENSORS_GYROSCOPE_Z_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.gyroscope.z_samples.value_statistics.max"
    )
    METADATA_SENSORS_GYROSCOPE_Z_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.gyroscope.z_samples.value_statistics.range"
    )
    METADATA_SENSORS_GYROSCOPE_Z_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.gyroscope.z_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_GYROSCOPE_Z_SAMPLES_METADATA: str = (
        "metadata.sensors.gyroscope.z_samples.metadata"
    )
    METADATA_SENSORS_GYROSCOPE_METADATA: str = "metadata.sensors.gyroscope.metadata"
    METADATA_SENSORS_IMAGE: str = "metadata.sensors.image"
    METADATA_SENSORS_IMAGE_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.image.sensor_description"
    )
    METADATA_SENSORS_IMAGE_TIMESTAMPS: str = "metadata.sensors.image.timestamps"
    METADATA_SENSORS_IMAGE_TIMESTAMPS_UNIT: str = "metadata.sensors.image.timestamps.unit"
    METADATA_SENSORS_IMAGE_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.image.timestamps.timestamps"
    )
    METADATA_SENSORS_IMAGE_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.image.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_IMAGE_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.image.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_IMAGE_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.image.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_IMAGE_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.image.timestamps.timestamp_statistics.standard_deviation"
    )
    METADATA_SENSORS_IMAGE_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.image.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_IMAGE_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.image.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_IMAGE_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.image.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_IMAGE_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.image.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_IMAGE_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.image.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_IMAGE_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.image.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_IMAGE_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.image.timestamps.metadata"
    )
    METADATA_SENSORS_IMAGE_SAMPLES: str = "metadata.sensors.image.samples"
    METADATA_SENSORS_IMAGE_IMAGE_CODEC: str = "metadata.sensors.image.image_codec"
    METADATA_SENSORS_IMAGE_METADATA: str = "metadata.sensors.image.metadata"
    METADATA_SENSORS_LIGHT: str = "metadata.sensors.light"
    METADATA_SENSORS_LIGHT_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.light.sensor_description"
    )
    METADATA_SENSORS_LIGHT_TIMESTAMPS: str = "metadata.sensors.light.timestamps"
    METADATA_SENSORS_LIGHT_TIMESTAMPS_UNIT: str = "metadata.sensors.light.timestamps.unit"
    METADATA_SENSORS_LIGHT_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.light.timestamps.timestamps"
    )
    METADATA_SENSORS_LIGHT_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.light.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_LIGHT_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.light.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_LIGHT_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.light.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_LIGHT_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.light.timestamps.timestamp_statistics.standard_deviation"
    )
    METADATA_SENSORS_LIGHT_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.light.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_LIGHT_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.light.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_LIGHT_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.light.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_LIGHT_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.light.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_LIGHT_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.light.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_LIGHT_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.light.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_LIGHT_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.light.timestamps.metadata"
    )
    METADATA_SENSORS_LIGHT_SAMPLES: str = "metadata.sensors.light.samples"
    METADATA_SENSORS_LIGHT_SAMPLES_UNIT: str = "metadata.sensors.light.samples.unit"
    METADATA_SENSORS_LIGHT_SAMPLES_VALUES: str = "metadata.sensors.light.samples.values"
    METADATA_SENSORS_LIGHT_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.light.samples.value_statistics"
    )
    METADATA_SENSORS_LIGHT_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.light.samples.value_statistics.count"
    )
    METADATA_SENSORS_LIGHT_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.light.samples.value_statistics.mean"
    )
    METADATA_SENSORS_LIGHT_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.light.samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_LIGHT_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.light.samples.value_statistics.min"
    )
    METADATA_SENSORS_LIGHT_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.light.samples.value_statistics.max"
    )
    METADATA_SENSORS_LIGHT_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.light.samples.value_statistics.range"
    )
    METADATA_SENSORS_LIGHT_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.light.samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LIGHT_SAMPLES_METADATA: str = "metadata.sensors.light.samples.metadata"
    METADATA_SENSORS_LIGHT_METADATA: str = "metadata.sensors.light.metadata"
    METADATA_SENSORS_LINEAR_ACCELERATION: str = "metadata.sensors.linear_acceleration"
    METADATA_SENSORS_LINEAR_ACCELERATION_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.linear_acceleration.sensor_description"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS: str = (
        "metadata.sensors.linear_acceleration.timestamps"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.linear_acceleration.timestamps.unit"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.linear_acceleration.timestamps.timestamps"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.linear_acceleration.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.linear_acceleration.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.linear_acceleration.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = "metadata.sensors.linear_acceleration.timestamps.timestamp_statistics.standard_deviation"
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.linear_acceleration.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.linear_acceleration.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.linear_acceleration.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.linear_acceleration.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.linear_acceleration.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.linear_acceleration.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.linear_acceleration.timestamps.metadata"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_X_SAMPLES: str = (
        "metadata.sensors.linear_acceleration.x_samples"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_X_SAMPLES_UNIT: str = (
        "metadata.sensors.linear_acceleration.x_samples.unit"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_X_SAMPLES_VALUES: str = (
        "metadata.sensors.linear_acceleration.x_samples.values"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_X_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.linear_acceleration.x_samples.value_statistics"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_X_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.linear_acceleration.x_samples.value_statistics.count"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_X_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.linear_acceleration.x_samples.value_statistics.mean"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_X_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.linear_acceleration.x_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_X_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.linear_acceleration.x_samples.value_statistics.min"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_X_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.linear_acceleration.x_samples.value_statistics.max"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_X_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.linear_acceleration.x_samples.value_statistics.range"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_X_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.linear_acceleration.x_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_X_SAMPLES_METADATA: str = (
        "metadata.sensors.linear_acceleration.x_samples.metadata"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Y_SAMPLES: str = (
        "metadata.sensors.linear_acceleration.y_samples"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Y_SAMPLES_UNIT: str = (
        "metadata.sensors.linear_acceleration.y_samples.unit"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Y_SAMPLES_VALUES: str = (
        "metadata.sensors.linear_acceleration.y_samples.values"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Y_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.linear_acceleration.y_samples.value_statistics"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Y_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.linear_acceleration.y_samples.value_statistics.count"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Y_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.linear_acceleration.y_samples.value_statistics.mean"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Y_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.linear_acceleration.y_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Y_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.linear_acceleration.y_samples.value_statistics.min"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Y_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.linear_acceleration.y_samples.value_statistics.max"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Y_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.linear_acceleration.y_samples.value_statistics.range"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Y_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.linear_acceleration.y_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Y_SAMPLES_METADATA: str = (
        "metadata.sensors.linear_acceleration.y_samples.metadata"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Z_SAMPLES: str = (
        "metadata.sensors.linear_acceleration.z_samples"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Z_SAMPLES_UNIT: str = (
        "metadata.sensors.linear_acceleration.z_samples.unit"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Z_SAMPLES_VALUES: str = (
        "metadata.sensors.linear_acceleration.z_samples.values"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Z_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.linear_acceleration.z_samples.value_statistics"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Z_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.linear_acceleration.z_samples.value_statistics.count"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Z_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.linear_acceleration.z_samples.value_statistics.mean"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Z_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.linear_acceleration.z_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Z_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.linear_acceleration.z_samples.value_statistics.min"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Z_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.linear_acceleration.z_samples.value_statistics.max"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Z_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.linear_acceleration.z_samples.value_statistics.range"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Z_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.linear_acceleration.z_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_Z_SAMPLES_METADATA: str = (
        "metadata.sensors.linear_acceleration.z_samples.metadata"
    )
    METADATA_SENSORS_LINEAR_ACCELERATION_METADATA: str = (
        "metadata.sensors.linear_acceleration.metadata"
    )
    METADATA_SENSORS_LOCATION: str = "metadata.sensors.location"
    METADATA_SENSORS_LOCATION_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.location.sensor_description"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS: str = "metadata.sensors.location.timestamps"
    METADATA_SENSORS_LOCATION_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.location.timestamps.unit"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.location.timestamps.timestamps"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.location.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.location.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.location.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.location.timestamps.timestamp_statistics.standard_deviation"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.location.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.location.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.location.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.location.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.location.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.location.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.location.timestamps.metadata"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS: str = (
        "metadata.sensors.location.timestamps_gps"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_UNIT: str = (
        "metadata.sensors.location.timestamps_gps.unit"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_TIMESTAMPS: str = (
        "metadata.sensors.location.timestamps_gps.timestamps"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.location.timestamps_gps.timestamp_statistics"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.location.timestamps_gps.timestamp_statistics.count"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.location.timestamps_gps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.location.timestamps_gps.timestamp_statistics.standard_deviation"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.location.timestamps_gps.timestamp_statistics.min"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.location.timestamps_gps.timestamp_statistics.max"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.location.timestamps_gps.timestamp_statistics.range"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.location.timestamps_gps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.location.timestamps_gps.mean_sample_rate"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.location.timestamps_gps.stdev_sample_rate"
    )
    METADATA_SENSORS_LOCATION_TIMESTAMPS_GPS_METADATA: str = (
        "metadata.sensors.location.timestamps_gps.metadata"
    )
    METADATA_SENSORS_LOCATION_LATITUDE_SAMPLES: str = (
        "metadata.sensors.location.latitude_samples"
    )
    METADATA_SENSORS_LOCATION_LATITUDE_SAMPLES_UNIT: str = (
        "metadata.sensors.location.latitude_samples.unit"
    )
    METADATA_SENSORS_LOCATION_LATITUDE_SAMPLES_VALUES: str = (
        "metadata.sensors.location.latitude_samples.values"
    )
    METADATA_SENSORS_LOCATION_LATITUDE_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.location.latitude_samples.value_statistics"
    )
    METADATA_SENSORS_LOCATION_LATITUDE_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.location.latitude_samples.value_statistics.count"
    )
    METADATA_SENSORS_LOCATION_LATITUDE_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.location.latitude_samples.value_statistics.mean"
    )
    METADATA_SENSORS_LOCATION_LATITUDE_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.location.latitude_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_LOCATION_LATITUDE_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.location.latitude_samples.value_statistics.min"
    )
    METADATA_SENSORS_LOCATION_LATITUDE_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.location.latitude_samples.value_statistics.max"
    )
    METADATA_SENSORS_LOCATION_LATITUDE_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.location.latitude_samples.value_statistics.range"
    )
    METADATA_SENSORS_LOCATION_LATITUDE_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.location.latitude_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LOCATION_LATITUDE_SAMPLES_METADATA: str = (
        "metadata.sensors.location.latitude_samples.metadata"
    )
    METADATA_SENSORS_LOCATION_LONGITUDE_SAMPLES: str = (
        "metadata.sensors.location.longitude_samples"
    )
    METADATA_SENSORS_LOCATION_LONGITUDE_SAMPLES_UNIT: str = (
        "metadata.sensors.location.longitude_samples.unit"
    )
    METADATA_SENSORS_LOCATION_LONGITUDE_SAMPLES_VALUES: str = (
        "metadata.sensors.location.longitude_samples.values"
    )
    METADATA_SENSORS_LOCATION_LONGITUDE_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.location.longitude_samples.value_statistics"
    )
    METADATA_SENSORS_LOCATION_LONGITUDE_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.location.longitude_samples.value_statistics.count"
    )
    METADATA_SENSORS_LOCATION_LONGITUDE_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.location.longitude_samples.value_statistics.mean"
    )
    METADATA_SENSORS_LOCATION_LONGITUDE_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.location.longitude_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_LOCATION_LONGITUDE_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.location.longitude_samples.value_statistics.min"
    )
    METADATA_SENSORS_LOCATION_LONGITUDE_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.location.longitude_samples.value_statistics.max"
    )
    METADATA_SENSORS_LOCATION_LONGITUDE_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.location.longitude_samples.value_statistics.range"
    )
    METADATA_SENSORS_LOCATION_LONGITUDE_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.location.longitude_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LOCATION_LONGITUDE_SAMPLES_METADATA: str = (
        "metadata.sensors.location.longitude_samples.metadata"
    )
    METADATA_SENSORS_LOCATION_ALTITUDE_SAMPLES: str = (
        "metadata.sensors.location.altitude_samples"
    )
    METADATA_SENSORS_LOCATION_ALTITUDE_SAMPLES_UNIT: str = (
        "metadata.sensors.location.altitude_samples.unit"
    )
    METADATA_SENSORS_LOCATION_ALTITUDE_SAMPLES_VALUES: str = (
        "metadata.sensors.location.altitude_samples.values"
    )
    METADATA_SENSORS_LOCATION_ALTITUDE_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.location.altitude_samples.value_statistics"
    )
    METADATA_SENSORS_LOCATION_ALTITUDE_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.location.altitude_samples.value_statistics.count"
    )
    METADATA_SENSORS_LOCATION_ALTITUDE_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.location.altitude_samples.value_statistics.mean"
    )
    METADATA_SENSORS_LOCATION_ALTITUDE_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.location.altitude_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_LOCATION_ALTITUDE_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.location.altitude_samples.value_statistics.min"
    )
    METADATA_SENSORS_LOCATION_ALTITUDE_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.location.altitude_samples.value_statistics.max"
    )
    METADATA_SENSORS_LOCATION_ALTITUDE_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.location.altitude_samples.value_statistics.range"
    )
    METADATA_SENSORS_LOCATION_ALTITUDE_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.location.altitude_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LOCATION_ALTITUDE_SAMPLES_METADATA: str = (
        "metadata.sensors.location.altitude_samples.metadata"
    )
    METADATA_SENSORS_LOCATION_SPEED_SAMPLES: str = "metadata.sensors.location.speed_samples"
    METADATA_SENSORS_LOCATION_SPEED_SAMPLES_UNIT: str = (
        "metadata.sensors.location.speed_samples.unit"
    )
    METADATA_SENSORS_LOCATION_SPEED_SAMPLES_VALUES: str = (
        "metadata.sensors.location.speed_samples.values"
    )
    METADATA_SENSORS_LOCATION_SPEED_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.location.speed_samples.value_statistics"
    )
    METADATA_SENSORS_LOCATION_SPEED_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.location.speed_samples.value_statistics.count"
    )
    METADATA_SENSORS_LOCATION_SPEED_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.location.speed_samples.value_statistics.mean"
    )
    METADATA_SENSORS_LOCATION_SPEED_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.location.speed_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_LOCATION_SPEED_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.location.speed_samples.value_statistics.min"
    )
    METADATA_SENSORS_LOCATION_SPEED_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.location.speed_samples.value_statistics.max"
    )
    METADATA_SENSORS_LOCATION_SPEED_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.location.speed_samples.value_statistics.range"
    )
    METADATA_SENSORS_LOCATION_SPEED_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.location.speed_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LOCATION_SPEED_SAMPLES_METADATA: str = (
        "metadata.sensors.location.speed_samples.metadata"
    )
    METADATA_SENSORS_LOCATION_BEARING_SAMPLES: str = (
        "metadata.sensors.location.bearing_samples"
    )
    METADATA_SENSORS_LOCATION_BEARING_SAMPLES_UNIT: str = (
        "metadata.sensors.location.bearing_samples.unit"
    )
    METADATA_SENSORS_LOCATION_BEARING_SAMPLES_VALUES: str = (
        "metadata.sensors.location.bearing_samples.values"
    )
    METADATA_SENSORS_LOCATION_BEARING_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.location.bearing_samples.value_statistics"
    )
    METADATA_SENSORS_LOCATION_BEARING_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.location.bearing_samples.value_statistics.count"
    )
    METADATA_SENSORS_LOCATION_BEARING_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.location.bearing_samples.value_statistics.mean"
    )
    METADATA_SENSORS_LOCATION_BEARING_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.location.bearing_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_LOCATION_BEARING_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.location.bearing_samples.value_statistics.min"
    )
    METADATA_SENSORS_LOCATION_BEARING_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.location.bearing_samples.value_statistics.max"
    )
    METADATA_SENSORS_LOCATION_BEARING_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.location.bearing_samples.value_statistics.range"
    )
    METADATA_SENSORS_LOCATION_BEARING_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.location.bearing_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LOCATION_BEARING_SAMPLES_METADATA: str = (
        "metadata.sensors.location.bearing_samples.metadata"
    )
    METADATA_SENSORS_LOCATION_HORIZONTAL_ACCURACY_SAMPLES: str = (
        "metadata.sensors.location.horizontal_accuracy_samples"
    )
    METADATA_SENSORS_LOCATION_HORIZONTAL_ACCURACY_SAMPLES_UNIT: str = (
        "metadata.sensors.location.horizontal_accuracy_samples.unit"
    )
    METADATA_SENSORS_LOCATION_HORIZONTAL_ACCURACY_SAMPLES_VALUES: str = (
        "metadata.sensors.location.horizontal_accuracy_samples.values"
    )
    METADATA_SENSORS_LOCATION_HORIZONTAL_ACCURACY_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.location.horizontal_accuracy_samples.value_statistics"
    )
    METADATA_SENSORS_LOCATION_HORIZONTAL_ACCURACY_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.location.horizontal_accuracy_samples.value_statistics.count"
    )
    METADATA_SENSORS_LOCATION_HORIZONTAL_ACCURACY_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.location.horizontal_accuracy_samples.value_statistics.mean"
    )
    METADATA_SENSORS_LOCATION_HORIZONTAL_ACCURACY_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = "metadata.sensors.location.horizontal_accuracy_samples.value_statistics.standard_deviation"
    METADATA_SENSORS_LOCATION_HORIZONTAL_ACCURACY_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.location.horizontal_accuracy_samples.value_statistics.min"
    )
    METADATA_SENSORS_LOCATION_HORIZONTAL_ACCURACY_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.location.horizontal_accuracy_samples.value_statistics.max"
    )
    METADATA_SENSORS_LOCATION_HORIZONTAL_ACCURACY_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.location.horizontal_accuracy_samples.value_statistics.range"
    )
    METADATA_SENSORS_LOCATION_HORIZONTAL_ACCURACY_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.location.horizontal_accuracy_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LOCATION_HORIZONTAL_ACCURACY_SAMPLES_METADATA: str = (
        "metadata.sensors.location.horizontal_accuracy_samples.metadata"
    )
    METADATA_SENSORS_LOCATION_VERTICAL_ACCURACY_SAMPLES: str = (
        "metadata.sensors.location.vertical_accuracy_samples"
    )
    METADATA_SENSORS_LOCATION_VERTICAL_ACCURACY_SAMPLES_UNIT: str = (
        "metadata.sensors.location.vertical_accuracy_samples.unit"
    )
    METADATA_SENSORS_LOCATION_VERTICAL_ACCURACY_SAMPLES_VALUES: str = (
        "metadata.sensors.location.vertical_accuracy_samples.values"
    )
    METADATA_SENSORS_LOCATION_VERTICAL_ACCURACY_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.location.vertical_accuracy_samples.value_statistics"
    )
    METADATA_SENSORS_LOCATION_VERTICAL_ACCURACY_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.location.vertical_accuracy_samples.value_statistics.count"
    )
    METADATA_SENSORS_LOCATION_VERTICAL_ACCURACY_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.location.vertical_accuracy_samples.value_statistics.mean"
    )
    METADATA_SENSORS_LOCATION_VERTICAL_ACCURACY_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = "metadata.sensors.location.vertical_accuracy_samples.value_statistics.standard_deviation"
    METADATA_SENSORS_LOCATION_VERTICAL_ACCURACY_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.location.vertical_accuracy_samples.value_statistics.min"
    )
    METADATA_SENSORS_LOCATION_VERTICAL_ACCURACY_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.location.vertical_accuracy_samples.value_statistics.max"
    )
    METADATA_SENSORS_LOCATION_VERTICAL_ACCURACY_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.location.vertical_accuracy_samples.value_statistics.range"
    )
    METADATA_SENSORS_LOCATION_VERTICAL_ACCURACY_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.location.vertical_accuracy_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LOCATION_VERTICAL_ACCURACY_SAMPLES_METADATA: str = (
        "metadata.sensors.location.vertical_accuracy_samples.metadata"
    )
    METADATA_SENSORS_LOCATION_SPEED_ACCURACY_SAMPLES: str = (
        "metadata.sensors.location.speed_accuracy_samples"
    )
    METADATA_SENSORS_LOCATION_SPEED_ACCURACY_SAMPLES_UNIT: str = (
        "metadata.sensors.location.speed_accuracy_samples.unit"
    )
    METADATA_SENSORS_LOCATION_SPEED_ACCURACY_SAMPLES_VALUES: str = (
        "metadata.sensors.location.speed_accuracy_samples.values"
    )
    METADATA_SENSORS_LOCATION_SPEED_ACCURACY_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.location.speed_accuracy_samples.value_statistics"
    )
    METADATA_SENSORS_LOCATION_SPEED_ACCURACY_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.location.speed_accuracy_samples.value_statistics.count"
    )
    METADATA_SENSORS_LOCATION_SPEED_ACCURACY_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.location.speed_accuracy_samples.value_statistics.mean"
    )
    METADATA_SENSORS_LOCATION_SPEED_ACCURACY_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = "metadata.sensors.location.speed_accuracy_samples.value_statistics.standard_deviation"
    METADATA_SENSORS_LOCATION_SPEED_ACCURACY_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.location.speed_accuracy_samples.value_statistics.min"
    )
    METADATA_SENSORS_LOCATION_SPEED_ACCURACY_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.location.speed_accuracy_samples.value_statistics.max"
    )
    METADATA_SENSORS_LOCATION_SPEED_ACCURACY_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.location.speed_accuracy_samples.value_statistics.range"
    )
    METADATA_SENSORS_LOCATION_SPEED_ACCURACY_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.location.speed_accuracy_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LOCATION_SPEED_ACCURACY_SAMPLES_METADATA: str = (
        "metadata.sensors.location.speed_accuracy_samples.metadata"
    )
    METADATA_SENSORS_LOCATION_BEARING_ACCURACY_SAMPLES: str = (
        "metadata.sensors.location.bearing_accuracy_samples"
    )
    METADATA_SENSORS_LOCATION_BEARING_ACCURACY_SAMPLES_UNIT: str = (
        "metadata.sensors.location.bearing_accuracy_samples.unit"
    )
    METADATA_SENSORS_LOCATION_BEARING_ACCURACY_SAMPLES_VALUES: str = (
        "metadata.sensors.location.bearing_accuracy_samples.values"
    )
    METADATA_SENSORS_LOCATION_BEARING_ACCURACY_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.location.bearing_accuracy_samples.value_statistics"
    )
    METADATA_SENSORS_LOCATION_BEARING_ACCURACY_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.location.bearing_accuracy_samples.value_statistics.count"
    )
    METADATA_SENSORS_LOCATION_BEARING_ACCURACY_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.location.bearing_accuracy_samples.value_statistics.mean"
    )
    METADATA_SENSORS_LOCATION_BEARING_ACCURACY_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = "metadata.sensors.location.bearing_accuracy_samples.value_statistics.standard_deviation"
    METADATA_SENSORS_LOCATION_BEARING_ACCURACY_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.location.bearing_accuracy_samples.value_statistics.min"
    )
    METADATA_SENSORS_LOCATION_BEARING_ACCURACY_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.location.bearing_accuracy_samples.value_statistics.max"
    )
    METADATA_SENSORS_LOCATION_BEARING_ACCURACY_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.location.bearing_accuracy_samples.value_statistics.range"
    )
    METADATA_SENSORS_LOCATION_BEARING_ACCURACY_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.location.bearing_accuracy_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_LOCATION_BEARING_ACCURACY_SAMPLES_METADATA: str = (
        "metadata.sensors.location.bearing_accuracy_samples.metadata"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION: str = (
        "metadata.sensors.location.last_best_location"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_LATITUDE_LONGITUDE_TIMESTAMP: str = (
        "metadata.sensors.location.last_best_location.latitude_longitude_timestamp"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_LATITUDE_LONGITUDE_TIMESTAMP_UNIT: str = (
        "metadata.sensors.location.last_best_location.latitude_longitude_timestamp.unit"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_LATITUDE_LONGITUDE_TIMESTAMP_MACH: str = (
        "metadata.sensors.location.last_best_location.latitude_longitude_timestamp.mach"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_LATITUDE_LONGITUDE_TIMESTAMP_GPS: str = (
        "metadata.sensors.location.last_best_location.latitude_longitude_timestamp.gps"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_LATITUDE_LONGITUDE_TIMESTAMP_METADATA: str = (
        "metadata.sensors.location.last_best_location.latitude_longitude_timestamp.metadata"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_ALTITUDE_TIMESTAMP: str = (
        "metadata.sensors.location.last_best_location.altitude_timestamp"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_ALTITUDE_TIMESTAMP_UNIT: str = (
        "metadata.sensors.location.last_best_location.altitude_timestamp.unit"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_ALTITUDE_TIMESTAMP_MACH: str = (
        "metadata.sensors.location.last_best_location.altitude_timestamp.mach"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_ALTITUDE_TIMESTAMP_GPS: str = (
        "metadata.sensors.location.last_best_location.altitude_timestamp.gps"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_ALTITUDE_TIMESTAMP_METADATA: str = (
        "metadata.sensors.location.last_best_location.altitude_timestamp.metadata"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_SPEED_TIMESTAMP: str = (
        "metadata.sensors.location.last_best_location.speed_timestamp"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_SPEED_TIMESTAMP_UNIT: str = (
        "metadata.sensors.location.last_best_location.speed_timestamp.unit"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_SPEED_TIMESTAMP_MACH: str = (
        "metadata.sensors.location.last_best_location.speed_timestamp.mach"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_SPEED_TIMESTAMP_GPS: str = (
        "metadata.sensors.location.last_best_location.speed_timestamp.gps"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_SPEED_TIMESTAMP_METADATA: str = (
        "metadata.sensors.location.last_best_location.speed_timestamp.metadata"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_BEARING_TIMESTAMP: str = (
        "metadata.sensors.location.last_best_location.bearing_timestamp"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_BEARING_TIMESTAMP_UNIT: str = (
        "metadata.sensors.location.last_best_location.bearing_timestamp.unit"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_BEARING_TIMESTAMP_MACH: str = (
        "metadata.sensors.location.last_best_location.bearing_timestamp.mach"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_BEARING_TIMESTAMP_GPS: str = (
        "metadata.sensors.location.last_best_location.bearing_timestamp.gps"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_BEARING_TIMESTAMP_METADATA: str = (
        "metadata.sensors.location.last_best_location.bearing_timestamp.metadata"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_LATITUDE_LONGITUDE_UNIT: str = (
        "metadata.sensors.location.last_best_location.latitude_longitude_unit"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_ALTITUDE_UNIT: str = (
        "metadata.sensors.location.last_best_location.altitude_unit"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_SPEED_UNIT: str = (
        "metadata.sensors.location.last_best_location.speed_unit"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_BEARING_UNIT: str = (
        "metadata.sensors.location.last_best_location.bearing_unit"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_VERTICAL_ACCURACY_UNIT: str = (
        "metadata.sensors.location.last_best_location.vertical_accuracy_unit"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_HORIZONTAL_ACCURACY_UNIT: str = (
        "metadata.sensors.location.last_best_location.horizontal_accuracy_unit"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_SPEED_ACCURACY_UNIT: str = (
        "metadata.sensors.location.last_best_location.speed_accuracy_unit"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_BEARING_ACCURACY_UNIT: str = (
        "metadata.sensors.location.last_best_location.bearing_accuracy_unit"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_LATITUDE: str = (
        "metadata.sensors.location.last_best_location.latitude"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_LONGITUDE: str = (
        "metadata.sensors.location.last_best_location.longitude"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_ALTITUDE: str = (
        "metadata.sensors.location.last_best_location.altitude"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_SPEED: str = (
        "metadata.sensors.location.last_best_location.speed"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_BEARING: str = (
        "metadata.sensors.location.last_best_location.bearing"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_VERTICAL_ACCURACY: str = (
        "metadata.sensors.location.last_best_location.vertical_accuracy"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_HORIZONTAL_ACCURACY: str = (
        "metadata.sensors.location.last_best_location.horizontal_accuracy"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_SPEED_ACCURACY: str = (
        "metadata.sensors.location.last_best_location.speed_accuracy"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_BEARING_ACCURACY: str = (
        "metadata.sensors.location.last_best_location.bearing_accuracy"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_SCORE: str = (
        "metadata.sensors.location.last_best_location.score"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_METHOD: str = (
        "metadata.sensors.location.last_best_location.method"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_LOCATION_PROVIDER: str = (
        "metadata.sensors.location.last_best_location.location_provider"
    )
    METADATA_SENSORS_LOCATION_LAST_BEST_LOCATION_METADATA: str = (
        "metadata.sensors.location.last_best_location.metadata"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION: str = (
        "metadata.sensors.location.overall_best_location"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_LATITUDE_LONGITUDE_TIMESTAMP: str = (
        "metadata.sensors.location.overall_best_location.latitude_longitude_timestamp"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_LATITUDE_LONGITUDE_TIMESTAMP_UNIT: str = (
        "metadata.sensors.location.overall_best_location.latitude_longitude_timestamp.unit"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_LATITUDE_LONGITUDE_TIMESTAMP_MACH: str = (
        "metadata.sensors.location.overall_best_location.latitude_longitude_timestamp.mach"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_LATITUDE_LONGITUDE_TIMESTAMP_GPS: str = (
        "metadata.sensors.location.overall_best_location.latitude_longitude_timestamp.gps"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_LATITUDE_LONGITUDE_TIMESTAMP_METADATA: str = "metadata.sensors.location.overall_best_location.latitude_longitude_timestamp.metadata"
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_ALTITUDE_TIMESTAMP: str = (
        "metadata.sensors.location.overall_best_location.altitude_timestamp"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_ALTITUDE_TIMESTAMP_UNIT: str = (
        "metadata.sensors.location.overall_best_location.altitude_timestamp.unit"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_ALTITUDE_TIMESTAMP_MACH: str = (
        "metadata.sensors.location.overall_best_location.altitude_timestamp.mach"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_ALTITUDE_TIMESTAMP_GPS: str = (
        "metadata.sensors.location.overall_best_location.altitude_timestamp.gps"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_ALTITUDE_TIMESTAMP_METADATA: str = (
        "metadata.sensors.location.overall_best_location.altitude_timestamp.metadata"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_SPEED_TIMESTAMP: str = (
        "metadata.sensors.location.overall_best_location.speed_timestamp"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_SPEED_TIMESTAMP_UNIT: str = (
        "metadata.sensors.location.overall_best_location.speed_timestamp.unit"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_SPEED_TIMESTAMP_MACH: str = (
        "metadata.sensors.location.overall_best_location.speed_timestamp.mach"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_SPEED_TIMESTAMP_GPS: str = (
        "metadata.sensors.location.overall_best_location.speed_timestamp.gps"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_SPEED_TIMESTAMP_METADATA: str = (
        "metadata.sensors.location.overall_best_location.speed_timestamp.metadata"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_BEARING_TIMESTAMP: str = (
        "metadata.sensors.location.overall_best_location.bearing_timestamp"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_BEARING_TIMESTAMP_UNIT: str = (
        "metadata.sensors.location.overall_best_location.bearing_timestamp.unit"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_BEARING_TIMESTAMP_MACH: str = (
        "metadata.sensors.location.overall_best_location.bearing_timestamp.mach"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_BEARING_TIMESTAMP_GPS: str = (
        "metadata.sensors.location.overall_best_location.bearing_timestamp.gps"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_BEARING_TIMESTAMP_METADATA: str = (
        "metadata.sensors.location.overall_best_location.bearing_timestamp.metadata"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_LATITUDE_LONGITUDE_UNIT: str = (
        "metadata.sensors.location.overall_best_location.latitude_longitude_unit"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_ALTITUDE_UNIT: str = (
        "metadata.sensors.location.overall_best_location.altitude_unit"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_SPEED_UNIT: str = (
        "metadata.sensors.location.overall_best_location.speed_unit"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_BEARING_UNIT: str = (
        "metadata.sensors.location.overall_best_location.bearing_unit"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_VERTICAL_ACCURACY_UNIT: str = (
        "metadata.sensors.location.overall_best_location.vertical_accuracy_unit"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_HORIZONTAL_ACCURACY_UNIT: str = (
        "metadata.sensors.location.overall_best_location.horizontal_accuracy_unit"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_SPEED_ACCURACY_UNIT: str = (
        "metadata.sensors.location.overall_best_location.speed_accuracy_unit"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_BEARING_ACCURACY_UNIT: str = (
        "metadata.sensors.location.overall_best_location.bearing_accuracy_unit"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_LATITUDE: str = (
        "metadata.sensors.location.overall_best_location.latitude"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_LONGITUDE: str = (
        "metadata.sensors.location.overall_best_location.longitude"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_ALTITUDE: str = (
        "metadata.sensors.location.overall_best_location.altitude"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_SPEED: str = (
        "metadata.sensors.location.overall_best_location.speed"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_BEARING: str = (
        "metadata.sensors.location.overall_best_location.bearing"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_VERTICAL_ACCURACY: str = (
        "metadata.sensors.location.overall_best_location.vertical_accuracy"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_HORIZONTAL_ACCURACY: str = (
        "metadata.sensors.location.overall_best_location.horizontal_accuracy"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_SPEED_ACCURACY: str = (
        "metadata.sensors.location.overall_best_location.speed_accuracy"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_BEARING_ACCURACY: str = (
        "metadata.sensors.location.overall_best_location.bearing_accuracy"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_SCORE: str = (
        "metadata.sensors.location.overall_best_location.score"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_METHOD: str = (
        "metadata.sensors.location.overall_best_location.method"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_LOCATION_PROVIDER: str = (
        "metadata.sensors.location.overall_best_location.location_provider"
    )
    METADATA_SENSORS_LOCATION_OVERALL_BEST_LOCATION_METADATA: str = (
        "metadata.sensors.location.overall_best_location.metadata"
    )
    METADATA_SENSORS_LOCATION_LOCATION_PERMISSIONS_GRANTED: str = (
        "metadata.sensors.location.location_permissions_granted"
    )
    METADATA_SENSORS_LOCATION_LOCATION_SERVICES_REQUESTED: str = (
        "metadata.sensors.location.location_services_requested"
    )
    METADATA_SENSORS_LOCATION_LOCATION_SERVICES_ENABLED: str = (
        "metadata.sensors.location.location_services_enabled"
    )
    METADATA_SENSORS_LOCATION_LOCATION_PROVIDERS: str = (
        "metadata.sensors.location.location_providers"
    )
    METADATA_SENSORS_LOCATION_METADATA: str = "metadata.sensors.location.metadata"
    METADATA_SENSORS_MAGNETOMETER: str = "metadata.sensors.magnetometer"
    METADATA_SENSORS_MAGNETOMETER_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.magnetometer.sensor_description"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS: str = (
        "metadata.sensors.magnetometer.timestamps"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.magnetometer.timestamps.unit"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.magnetometer.timestamps.timestamps"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.magnetometer.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.magnetometer.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.magnetometer.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.magnetometer.timestamps.timestamp_statistics.standard_deviation"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.magnetometer.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.magnetometer.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.magnetometer.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.magnetometer.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.magnetometer.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.magnetometer.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_MAGNETOMETER_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.magnetometer.timestamps.metadata"
    )
    METADATA_SENSORS_MAGNETOMETER_X_SAMPLES: str = "metadata.sensors.magnetometer.x_samples"
    METADATA_SENSORS_MAGNETOMETER_X_SAMPLES_UNIT: str = (
        "metadata.sensors.magnetometer.x_samples.unit"
    )
    METADATA_SENSORS_MAGNETOMETER_X_SAMPLES_VALUES: str = (
        "metadata.sensors.magnetometer.x_samples.values"
    )
    METADATA_SENSORS_MAGNETOMETER_X_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.magnetometer.x_samples.value_statistics"
    )
    METADATA_SENSORS_MAGNETOMETER_X_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.magnetometer.x_samples.value_statistics.count"
    )
    METADATA_SENSORS_MAGNETOMETER_X_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.magnetometer.x_samples.value_statistics.mean"
    )
    METADATA_SENSORS_MAGNETOMETER_X_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.magnetometer.x_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_MAGNETOMETER_X_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.magnetometer.x_samples.value_statistics.min"
    )
    METADATA_SENSORS_MAGNETOMETER_X_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.magnetometer.x_samples.value_statistics.max"
    )
    METADATA_SENSORS_MAGNETOMETER_X_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.magnetometer.x_samples.value_statistics.range"
    )
    METADATA_SENSORS_MAGNETOMETER_X_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.magnetometer.x_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_MAGNETOMETER_X_SAMPLES_METADATA: str = (
        "metadata.sensors.magnetometer.x_samples.metadata"
    )
    METADATA_SENSORS_MAGNETOMETER_Y_SAMPLES: str = "metadata.sensors.magnetometer.y_samples"
    METADATA_SENSORS_MAGNETOMETER_Y_SAMPLES_UNIT: str = (
        "metadata.sensors.magnetometer.y_samples.unit"
    )
    METADATA_SENSORS_MAGNETOMETER_Y_SAMPLES_VALUES: str = (
        "metadata.sensors.magnetometer.y_samples.values"
    )
    METADATA_SENSORS_MAGNETOMETER_Y_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.magnetometer.y_samples.value_statistics"
    )
    METADATA_SENSORS_MAGNETOMETER_Y_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.magnetometer.y_samples.value_statistics.count"
    )
    METADATA_SENSORS_MAGNETOMETER_Y_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.magnetometer.y_samples.value_statistics.mean"
    )
    METADATA_SENSORS_MAGNETOMETER_Y_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.magnetometer.y_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_MAGNETOMETER_Y_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.magnetometer.y_samples.value_statistics.min"
    )
    METADATA_SENSORS_MAGNETOMETER_Y_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.magnetometer.y_samples.value_statistics.max"
    )
    METADATA_SENSORS_MAGNETOMETER_Y_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.magnetometer.y_samples.value_statistics.range"
    )
    METADATA_SENSORS_MAGNETOMETER_Y_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.magnetometer.y_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_MAGNETOMETER_Y_SAMPLES_METADATA: str = (
        "metadata.sensors.magnetometer.y_samples.metadata"
    )
    METADATA_SENSORS_MAGNETOMETER_Z_SAMPLES: str = "metadata.sensors.magnetometer.z_samples"
    METADATA_SENSORS_MAGNETOMETER_Z_SAMPLES_UNIT: str = (
        "metadata.sensors.magnetometer.z_samples.unit"
    )
    METADATA_SENSORS_MAGNETOMETER_Z_SAMPLES_VALUES: str = (
        "metadata.sensors.magnetometer.z_samples.values"
    )
    METADATA_SENSORS_MAGNETOMETER_Z_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.magnetometer.z_samples.value_statistics"
    )
    METADATA_SENSORS_MAGNETOMETER_Z_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.magnetometer.z_samples.value_statistics.count"
    )
    METADATA_SENSORS_MAGNETOMETER_Z_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.magnetometer.z_samples.value_statistics.mean"
    )
    METADATA_SENSORS_MAGNETOMETER_Z_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.magnetometer.z_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_MAGNETOMETER_Z_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.magnetometer.z_samples.value_statistics.min"
    )
    METADATA_SENSORS_MAGNETOMETER_Z_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.magnetometer.z_samples.value_statistics.max"
    )
    METADATA_SENSORS_MAGNETOMETER_Z_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.magnetometer.z_samples.value_statistics.range"
    )
    METADATA_SENSORS_MAGNETOMETER_Z_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.magnetometer.z_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_MAGNETOMETER_Z_SAMPLES_METADATA: str = (
        "metadata.sensors.magnetometer.z_samples.metadata"
    )
    METADATA_SENSORS_MAGNETOMETER_METADATA: str = "metadata.sensors.magnetometer.metadata"
    METADATA_SENSORS_ORIENTATION: str = "metadata.sensors.orientation"
    METADATA_SENSORS_ORIENTATION_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.orientation.sensor_description"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS: str = "metadata.sensors.orientation.timestamps"
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.orientation.timestamps.unit"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.orientation.timestamps.timestamps"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.orientation.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.orientation.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.orientation.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.orientation.timestamps.timestamp_statistics.standard_deviation"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.orientation.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.orientation.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.orientation.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.orientation.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.orientation.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.orientation.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_ORIENTATION_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.orientation.timestamps.metadata"
    )
    METADATA_SENSORS_ORIENTATION_X_SAMPLES: str = "metadata.sensors.orientation.x_samples"
    METADATA_SENSORS_ORIENTATION_X_SAMPLES_UNIT: str = (
        "metadata.sensors.orientation.x_samples.unit"
    )
    METADATA_SENSORS_ORIENTATION_X_SAMPLES_VALUES: str = (
        "metadata.sensors.orientation.x_samples.values"
    )
    METADATA_SENSORS_ORIENTATION_X_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.orientation.x_samples.value_statistics"
    )
    METADATA_SENSORS_ORIENTATION_X_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.orientation.x_samples.value_statistics.count"
    )
    METADATA_SENSORS_ORIENTATION_X_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.orientation.x_samples.value_statistics.mean"
    )
    METADATA_SENSORS_ORIENTATION_X_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.orientation.x_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_ORIENTATION_X_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.orientation.x_samples.value_statistics.min"
    )
    METADATA_SENSORS_ORIENTATION_X_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.orientation.x_samples.value_statistics.max"
    )
    METADATA_SENSORS_ORIENTATION_X_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.orientation.x_samples.value_statistics.range"
    )
    METADATA_SENSORS_ORIENTATION_X_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.orientation.x_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_ORIENTATION_X_SAMPLES_METADATA: str = (
        "metadata.sensors.orientation.x_samples.metadata"
    )
    METADATA_SENSORS_ORIENTATION_Y_SAMPLES: str = "metadata.sensors.orientation.y_samples"
    METADATA_SENSORS_ORIENTATION_Y_SAMPLES_UNIT: str = (
        "metadata.sensors.orientation.y_samples.unit"
    )
    METADATA_SENSORS_ORIENTATION_Y_SAMPLES_VALUES: str = (
        "metadata.sensors.orientation.y_samples.values"
    )
    METADATA_SENSORS_ORIENTATION_Y_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.orientation.y_samples.value_statistics"
    )
    METADATA_SENSORS_ORIENTATION_Y_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.orientation.y_samples.value_statistics.count"
    )
    METADATA_SENSORS_ORIENTATION_Y_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.orientation.y_samples.value_statistics.mean"
    )
    METADATA_SENSORS_ORIENTATION_Y_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.orientation.y_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_ORIENTATION_Y_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.orientation.y_samples.value_statistics.min"
    )
    METADATA_SENSORS_ORIENTATION_Y_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.orientation.y_samples.value_statistics.max"
    )
    METADATA_SENSORS_ORIENTATION_Y_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.orientation.y_samples.value_statistics.range"
    )
    METADATA_SENSORS_ORIENTATION_Y_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.orientation.y_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_ORIENTATION_Y_SAMPLES_METADATA: str = (
        "metadata.sensors.orientation.y_samples.metadata"
    )
    METADATA_SENSORS_ORIENTATION_Z_SAMPLES: str = "metadata.sensors.orientation.z_samples"
    METADATA_SENSORS_ORIENTATION_Z_SAMPLES_UNIT: str = (
        "metadata.sensors.orientation.z_samples.unit"
    )
    METADATA_SENSORS_ORIENTATION_Z_SAMPLES_VALUES: str = (
        "metadata.sensors.orientation.z_samples.values"
    )
    METADATA_SENSORS_ORIENTATION_Z_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.orientation.z_samples.value_statistics"
    )
    METADATA_SENSORS_ORIENTATION_Z_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.orientation.z_samples.value_statistics.count"
    )
    METADATA_SENSORS_ORIENTATION_Z_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.orientation.z_samples.value_statistics.mean"
    )
    METADATA_SENSORS_ORIENTATION_Z_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.orientation.z_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_ORIENTATION_Z_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.orientation.z_samples.value_statistics.min"
    )
    METADATA_SENSORS_ORIENTATION_Z_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.orientation.z_samples.value_statistics.max"
    )
    METADATA_SENSORS_ORIENTATION_Z_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.orientation.z_samples.value_statistics.range"
    )
    METADATA_SENSORS_ORIENTATION_Z_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.orientation.z_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_ORIENTATION_Z_SAMPLES_METADATA: str = (
        "metadata.sensors.orientation.z_samples.metadata"
    )
    METADATA_SENSORS_ORIENTATION_METADATA: str = "metadata.sensors.orientation.metadata"
    METADATA_SENSORS_PRESSURE: str = "metadata.sensors.pressure"
    METADATA_SENSORS_PRESSURE_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.pressure.sensor_description"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS: str = "metadata.sensors.pressure.timestamps"
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.pressure.timestamps.unit"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.pressure.timestamps.timestamps"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.pressure.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.pressure.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.pressure.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.pressure.timestamps.timestamp_statistics.standard_deviation"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.pressure.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.pressure.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.pressure.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.pressure.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.pressure.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.pressure.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_PRESSURE_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.pressure.timestamps.metadata"
    )
    METADATA_SENSORS_PRESSURE_SAMPLES: str = "metadata.sensors.pressure.samples"
    METADATA_SENSORS_PRESSURE_SAMPLES_UNIT: str = "metadata.sensors.pressure.samples.unit"
    METADATA_SENSORS_PRESSURE_SAMPLES_VALUES: str = (
        "metadata.sensors.pressure.samples.values"
    )
    METADATA_SENSORS_PRESSURE_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.pressure.samples.value_statistics"
    )
    METADATA_SENSORS_PRESSURE_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.pressure.samples.value_statistics.count"
    )
    METADATA_SENSORS_PRESSURE_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.pressure.samples.value_statistics.mean"
    )
    METADATA_SENSORS_PRESSURE_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.pressure.samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_PRESSURE_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.pressure.samples.value_statistics.min"
    )
    METADATA_SENSORS_PRESSURE_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.pressure.samples.value_statistics.max"
    )
    METADATA_SENSORS_PRESSURE_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.pressure.samples.value_statistics.range"
    )
    METADATA_SENSORS_PRESSURE_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.pressure.samples.value_statistics.metadata"
    )
    METADATA_SENSORS_PRESSURE_SAMPLES_METADATA: str = (
        "metadata.sensors.pressure.samples.metadata"
    )
    METADATA_SENSORS_PRESSURE_METADATA: str = "metadata.sensors.pressure.metadata"
    METADATA_SENSORS_PROXIMITY: str = "metadata.sensors.proximity"
    METADATA_SENSORS_PROXIMITY_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.proximity.sensor_description"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS: str = "metadata.sensors.proximity.timestamps"
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.proximity.timestamps.unit"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.proximity.timestamps.timestamps"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.proximity.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.proximity.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.proximity.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.proximity.timestamps.timestamp_statistics.standard_deviation"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.proximity.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.proximity.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.proximity.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.proximity.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.proximity.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.proximity.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_PROXIMITY_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.proximity.timestamps.metadata"
    )
    METADATA_SENSORS_PROXIMITY_SAMPLES: str = "metadata.sensors.proximity.samples"
    METADATA_SENSORS_PROXIMITY_SAMPLES_UNIT: str = "metadata.sensors.proximity.samples.unit"
    METADATA_SENSORS_PROXIMITY_SAMPLES_VALUES: str = (
        "metadata.sensors.proximity.samples.values"
    )
    METADATA_SENSORS_PROXIMITY_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.proximity.samples.value_statistics"
    )
    METADATA_SENSORS_PROXIMITY_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.proximity.samples.value_statistics.count"
    )
    METADATA_SENSORS_PROXIMITY_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.proximity.samples.value_statistics.mean"
    )
    METADATA_SENSORS_PROXIMITY_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.proximity.samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_PROXIMITY_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.proximity.samples.value_statistics.min"
    )
    METADATA_SENSORS_PROXIMITY_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.proximity.samples.value_statistics.max"
    )
    METADATA_SENSORS_PROXIMITY_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.proximity.samples.value_statistics.range"
    )
    METADATA_SENSORS_PROXIMITY_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.proximity.samples.value_statistics.metadata"
    )
    METADATA_SENSORS_PROXIMITY_SAMPLES_METADATA: str = (
        "metadata.sensors.proximity.samples.metadata"
    )
    METADATA_SENSORS_PROXIMITY_METADATA: str = "metadata.sensors.proximity.metadata"
    METADATA_SENSORS_RELATIVE_HUMIDITY: str = "metadata.sensors.relative_humidity"
    METADATA_SENSORS_RELATIVE_HUMIDITY_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.relative_humidity.sensor_description"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS: str = (
        "metadata.sensors.relative_humidity.timestamps"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.relative_humidity.timestamps.unit"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.relative_humidity.timestamps.timestamps"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.relative_humidity.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.relative_humidity.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.relative_humidity.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = "metadata.sensors.relative_humidity.timestamps.timestamp_statistics.standard_deviation"
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.relative_humidity.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.relative_humidity.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.relative_humidity.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.relative_humidity.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.relative_humidity.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.relative_humidity.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.relative_humidity.timestamps.metadata"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_SAMPLES: str = (
        "metadata.sensors.relative_humidity.samples"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_SAMPLES_UNIT: str = (
        "metadata.sensors.relative_humidity.samples.unit"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_SAMPLES_VALUES: str = (
        "metadata.sensors.relative_humidity.samples.values"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.relative_humidity.samples.value_statistics"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.relative_humidity.samples.value_statistics.count"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.relative_humidity.samples.value_statistics.mean"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.relative_humidity.samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.relative_humidity.samples.value_statistics.min"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.relative_humidity.samples.value_statistics.max"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.relative_humidity.samples.value_statistics.range"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.relative_humidity.samples.value_statistics.metadata"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_SAMPLES_METADATA: str = (
        "metadata.sensors.relative_humidity.samples.metadata"
    )
    METADATA_SENSORS_RELATIVE_HUMIDITY_METADATA: str = (
        "metadata.sensors.relative_humidity.metadata"
    )
    METADATA_SENSORS_ROTATION_VECTOR: str = "metadata.sensors.rotation_vector"
    METADATA_SENSORS_ROTATION_VECTOR_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.rotation_vector.sensor_description"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS: str = (
        "metadata.sensors.rotation_vector.timestamps"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.rotation_vector.timestamps.unit"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.rotation_vector.timestamps.timestamps"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.rotation_vector.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.rotation_vector.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.rotation_vector.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = "metadata.sensors.rotation_vector.timestamps.timestamp_statistics.standard_deviation"
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.rotation_vector.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.rotation_vector.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.rotation_vector.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.rotation_vector.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.rotation_vector.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.rotation_vector.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_ROTATION_VECTOR_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.rotation_vector.timestamps.metadata"
    )
    METADATA_SENSORS_ROTATION_VECTOR_X_SAMPLES: str = (
        "metadata.sensors.rotation_vector.x_samples"
    )
    METADATA_SENSORS_ROTATION_VECTOR_X_SAMPLES_UNIT: str = (
        "metadata.sensors.rotation_vector.x_samples.unit"
    )
    METADATA_SENSORS_ROTATION_VECTOR_X_SAMPLES_VALUES: str = (
        "metadata.sensors.rotation_vector.x_samples.values"
    )
    METADATA_SENSORS_ROTATION_VECTOR_X_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.rotation_vector.x_samples.value_statistics"
    )
    METADATA_SENSORS_ROTATION_VECTOR_X_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.rotation_vector.x_samples.value_statistics.count"
    )
    METADATA_SENSORS_ROTATION_VECTOR_X_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.rotation_vector.x_samples.value_statistics.mean"
    )
    METADATA_SENSORS_ROTATION_VECTOR_X_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.rotation_vector.x_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_ROTATION_VECTOR_X_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.rotation_vector.x_samples.value_statistics.min"
    )
    METADATA_SENSORS_ROTATION_VECTOR_X_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.rotation_vector.x_samples.value_statistics.max"
    )
    METADATA_SENSORS_ROTATION_VECTOR_X_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.rotation_vector.x_samples.value_statistics.range"
    )
    METADATA_SENSORS_ROTATION_VECTOR_X_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.rotation_vector.x_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_ROTATION_VECTOR_X_SAMPLES_METADATA: str = (
        "metadata.sensors.rotation_vector.x_samples.metadata"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Y_SAMPLES: str = (
        "metadata.sensors.rotation_vector.y_samples"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Y_SAMPLES_UNIT: str = (
        "metadata.sensors.rotation_vector.y_samples.unit"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Y_SAMPLES_VALUES: str = (
        "metadata.sensors.rotation_vector.y_samples.values"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Y_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.rotation_vector.y_samples.value_statistics"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Y_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.rotation_vector.y_samples.value_statistics.count"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Y_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.rotation_vector.y_samples.value_statistics.mean"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Y_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.rotation_vector.y_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Y_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.rotation_vector.y_samples.value_statistics.min"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Y_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.rotation_vector.y_samples.value_statistics.max"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Y_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.rotation_vector.y_samples.value_statistics.range"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Y_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.rotation_vector.y_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Y_SAMPLES_METADATA: str = (
        "metadata.sensors.rotation_vector.y_samples.metadata"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Z_SAMPLES: str = (
        "metadata.sensors.rotation_vector.z_samples"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Z_SAMPLES_UNIT: str = (
        "metadata.sensors.rotation_vector.z_samples.unit"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Z_SAMPLES_VALUES: str = (
        "metadata.sensors.rotation_vector.z_samples.values"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Z_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.rotation_vector.z_samples.value_statistics"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Z_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.rotation_vector.z_samples.value_statistics.count"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Z_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.rotation_vector.z_samples.value_statistics.mean"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Z_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.rotation_vector.z_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Z_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.rotation_vector.z_samples.value_statistics.min"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Z_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.rotation_vector.z_samples.value_statistics.max"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Z_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.rotation_vector.z_samples.value_statistics.range"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Z_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.rotation_vector.z_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_ROTATION_VECTOR_Z_SAMPLES_METADATA: str = (
        "metadata.sensors.rotation_vector.z_samples.metadata"
    )
    METADATA_SENSORS_ROTATION_VECTOR_METADATA: str = (
        "metadata.sensors.rotation_vector.metadata"
    )
    METADATA_SENSORS_VELOCITY: str = "metadata.sensors.velocity"
    METADATA_SENSORS_VELOCITY_SENSOR_DESCRIPTION: str = (
        "metadata.sensors.velocity.sensor_description"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS: str = "metadata.sensors.velocity.timestamps"
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_UNIT: str = (
        "metadata.sensors.velocity.timestamps.unit"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.sensors.velocity.timestamps.timestamps"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.sensors.velocity.timestamps.timestamp_statistics"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.sensors.velocity.timestamps.timestamp_statistics.count"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.sensors.velocity.timestamps.timestamp_statistics.mean"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.velocity.timestamps.timestamp_statistics.standard_deviation"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.sensors.velocity.timestamps.timestamp_statistics.min"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.sensors.velocity.timestamps.timestamp_statistics.max"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.sensors.velocity.timestamps.timestamp_statistics.range"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.sensors.velocity.timestamps.timestamp_statistics.metadata"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.sensors.velocity.timestamps.mean_sample_rate"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.sensors.velocity.timestamps.stdev_sample_rate"
    )
    METADATA_SENSORS_VELOCITY_TIMESTAMPS_METADATA: str = (
        "metadata.sensors.velocity.timestamps.metadata"
    )
    METADATA_SENSORS_VELOCITY_X_SAMPLES: str = "metadata.sensors.velocity.x_samples"
    METADATA_SENSORS_VELOCITY_X_SAMPLES_UNIT: str = (
        "metadata.sensors.velocity.x_samples.unit"
    )
    METADATA_SENSORS_VELOCITY_X_SAMPLES_VALUES: str = (
        "metadata.sensors.velocity.x_samples.values"
    )
    METADATA_SENSORS_VELOCITY_X_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.velocity.x_samples.value_statistics"
    )
    METADATA_SENSORS_VELOCITY_X_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.velocity.x_samples.value_statistics.count"
    )
    METADATA_SENSORS_VELOCITY_X_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.velocity.x_samples.value_statistics.mean"
    )
    METADATA_SENSORS_VELOCITY_X_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.velocity.x_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_VELOCITY_X_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.velocity.x_samples.value_statistics.min"
    )
    METADATA_SENSORS_VELOCITY_X_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.velocity.x_samples.value_statistics.max"
    )
    METADATA_SENSORS_VELOCITY_X_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.velocity.x_samples.value_statistics.range"
    )
    METADATA_SENSORS_VELOCITY_X_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.velocity.x_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_VELOCITY_X_SAMPLES_METADATA: str = (
        "metadata.sensors.velocity.x_samples.metadata"
    )
    METADATA_SENSORS_VELOCITY_Y_SAMPLES: str = "metadata.sensors.velocity.y_samples"
    METADATA_SENSORS_VELOCITY_Y_SAMPLES_UNIT: str = (
        "metadata.sensors.velocity.y_samples.unit"
    )
    METADATA_SENSORS_VELOCITY_Y_SAMPLES_VALUES: str = (
        "metadata.sensors.velocity.y_samples.values"
    )
    METADATA_SENSORS_VELOCITY_Y_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.velocity.y_samples.value_statistics"
    )
    METADATA_SENSORS_VELOCITY_Y_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.velocity.y_samples.value_statistics.count"
    )
    METADATA_SENSORS_VELOCITY_Y_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.velocity.y_samples.value_statistics.mean"
    )
    METADATA_SENSORS_VELOCITY_Y_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.velocity.y_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_VELOCITY_Y_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.velocity.y_samples.value_statistics.min"
    )
    METADATA_SENSORS_VELOCITY_Y_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.velocity.y_samples.value_statistics.max"
    )
    METADATA_SENSORS_VELOCITY_Y_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.velocity.y_samples.value_statistics.range"
    )
    METADATA_SENSORS_VELOCITY_Y_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.velocity.y_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_VELOCITY_Y_SAMPLES_METADATA: str = (
        "metadata.sensors.velocity.y_samples.metadata"
    )
    METADATA_SENSORS_VELOCITY_Z_SAMPLES: str = "metadata.sensors.velocity.z_samples"
    METADATA_SENSORS_VELOCITY_Z_SAMPLES_UNIT: str = (
        "metadata.sensors.velocity.z_samples.unit"
    )
    METADATA_SENSORS_VELOCITY_Z_SAMPLES_VALUES: str = (
        "metadata.sensors.velocity.z_samples.values"
    )
    METADATA_SENSORS_VELOCITY_Z_SAMPLES_VALUE_STATISTICS: str = (
        "metadata.sensors.velocity.z_samples.value_statistics"
    )
    METADATA_SENSORS_VELOCITY_Z_SAMPLES_VALUE_STATISTICS_COUNT: str = (
        "metadata.sensors.velocity.z_samples.value_statistics.count"
    )
    METADATA_SENSORS_VELOCITY_Z_SAMPLES_VALUE_STATISTICS_MEAN: str = (
        "metadata.sensors.velocity.z_samples.value_statistics.mean"
    )
    METADATA_SENSORS_VELOCITY_Z_SAMPLES_VALUE_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.sensors.velocity.z_samples.value_statistics.standard_deviation"
    )
    METADATA_SENSORS_VELOCITY_Z_SAMPLES_VALUE_STATISTICS_MIN: str = (
        "metadata.sensors.velocity.z_samples.value_statistics.min"
    )
    METADATA_SENSORS_VELOCITY_Z_SAMPLES_VALUE_STATISTICS_MAX: str = (
        "metadata.sensors.velocity.z_samples.value_statistics.max"
    )
    METADATA_SENSORS_VELOCITY_Z_SAMPLES_VALUE_STATISTICS_RANGE: str = (
        "metadata.sensors.velocity.z_samples.value_statistics.range"
    )
    METADATA_SENSORS_VELOCITY_Z_SAMPLES_VALUE_STATISTICS_METADATA: str = (
        "metadata.sensors.velocity.z_samples.value_statistics.metadata"
    )
    METADATA_SENSORS_VELOCITY_Z_SAMPLES_METADATA: str = (
        "metadata.sensors.velocity.z_samples.metadata"
    )
    METADATA_SENSORS_VELOCITY_METADATA: str = "metadata.sensors.velocity.metadata"
    METADATA_SENSORS_METADATA: str = "metadata.sensors.metadata"
    METADATA_EVENT_STREAMS: str = "metadata.event_streams"
    METADATA_EVENT_STREAMS_NAME: str = "metadata.event_streams.name"
    METADATA_EVENT_STREAMS_TIMESTAMPS: str = "metadata.event_streams.timestamps"
    METADATA_EVENT_STREAMS_TIMESTAMPS_UNIT: str = "metadata.event_streams.timestamps.unit"
    METADATA_EVENT_STREAMS_TIMESTAMPS_TIMESTAMPS: str = (
        "metadata.event_streams.timestamps.timestamps"
    )
    METADATA_EVENT_STREAMS_TIMESTAMPS_TIMESTAMP_STATISTICS: str = (
        "metadata.event_streams.timestamps.timestamp_statistics"
    )
    METADATA_EVENT_STREAMS_TIMESTAMPS_TIMESTAMP_STATISTICS_COUNT: str = (
        "metadata.event_streams.timestamps.timestamp_statistics.count"
    )
    METADATA_EVENT_STREAMS_TIMESTAMPS_TIMESTAMP_STATISTICS_MEAN: str = (
        "metadata.event_streams.timestamps.timestamp_statistics.mean"
    )
    METADATA_EVENT_STREAMS_TIMESTAMPS_TIMESTAMP_STATISTICS_STANDARD_DEVIATION: str = (
        "metadata.event_streams.timestamps.timestamp_statistics.standard_deviation"
    )
    METADATA_EVENT_STREAMS_TIMESTAMPS_TIMESTAMP_STATISTICS_MIN: str = (
        "metadata.event_streams.timestamps.timestamp_statistics.min"
    )
    METADATA_EVENT_STREAMS_TIMESTAMPS_TIMESTAMP_STATISTICS_MAX: str = (
        "metadata.event_streams.timestamps.timestamp_statistics.max"
    )
    METADATA_EVENT_STREAMS_TIMESTAMPS_TIMESTAMP_STATISTICS_RANGE: str = (
        "metadata.event_streams.timestamps.timestamp_statistics.range"
    )
    METADATA_EVENT_STREAMS_TIMESTAMPS_TIMESTAMP_STATISTICS_METADATA: str = (
        "metadata.event_streams.timestamps.timestamp_statistics.metadata"
    )
    METADATA_EVENT_STREAMS_TIMESTAMPS_MEAN_SAMPLE_RATE: str = (
        "metadata.event_streams.timestamps.mean_sample_rate"
    )
    METADATA_EVENT_STREAMS_TIMESTAMPS_STDEV_SAMPLE_RATE: str = (
        "metadata.event_streams.timestamps.stdev_sample_rate"
    )
    METADATA_EVENT_STREAMS_TIMESTAMPS_METADATA: str = (
        "metadata.event_streams.timestamps.metadata"
    )
    METADATA_EVENT_STREAMS_EVENTS: str = "metadata.event_streams.events"
    METADATA_EVENT_STREAMS_EVENTS_DESCRIPTION: str = (
        "metadata.event_streams.events.description"
    )
    METADATA_EVENT_STREAMS_EVENTS_STRING_PAYLOAD: str = (
        "metadata.event_streams.events.string_payload"
    )
    METADATA_EVENT_STREAMS_EVENTS_NUMERIC_PAYLOAD: str = (
        "metadata.event_streams.events.numeric_payload"
    )
    METADATA_EVENT_STREAMS_EVENTS_BOOLEAN_PAYLOAD: str = (
        "metadata.event_streams.events.boolean_payload"
    )
    METADATA_EVENT_STREAMS_EVENTS_BYTE_PAYLOAD: str = (
        "metadata.event_streams.events.byte_payload"
    )
    METADATA_EVENT_STREAMS_EVENTS_METADATA: str = "metadata.event_streams.events.metadata"
    METADATA_EVENT_STREAMS_METADATA: str = "metadata.event_streams.metadata"
    METADATA_METADATA: str = "metadata.metadata"
    ADDITIONAL_METADATA: str = "additional_metadata"
    ADDITIONAL_METADATA_DATA_KEY: str = "additional_metadata.data_key"